SystemOrganization addCategory: #ScriptLoader13!

!MCWorkingCopy methodsFor: '*scriptloader13' stamp: 'sd 3/24/2008 17:13'!
theCachedRepository

	^ MCCacheRepository default! !

Object subclass: #Loader
	instanceVariableNames: ''
	classVariableNames: 'PackagesBeforeLastLoad'
	poolDictionaries: ''
	category: 'ScriptLoader13'!

!Loader commentStamp: 'LaurentLaffont 3/4/2011 22:44' prior: 0!
I'm an abstract class which collect some infos about package and system (versions, dirty).
#currentChangedPackages instance method and #currentMajorVersionNumber class are missing and provided by my wellknown subclass ScriptLoader (see ScriptLoader comment).


Stef: This is a class that was extracted from scriptLoader because I want to slowly get in place a loader infrastructure based on Metacello.!

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
packageToBeTestedFolderName

	^ 'packages-to-be-tested'! !

!Loader class methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:22'!
waitingCacheFolder
	^ (FileDirectory default directoryNamed: self packageToBeTestedFolderName)
		assureExistence;
		yourself

	! !

!Loader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2010 17:41'!
allCurrentVersions
	"self new allCurrentVersions"
	
	| copies names |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	names := copies collect:
		[:ea |  ea ancestry ancestorString ].
	^ names reject: #isEmpty! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:51'!
currentChangedPackages
	"self new currentChangedPackages" 
	
	^  self currentPackages select: [:each |
		each needsSaving or: [
			(PackagesBeforeLastLoad includes: each ancestry ancestorString) not ] ]! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumber

	^ self class currentMajorVersionNumber ! !

!Loader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2010 17:34'!
currentMajorVersionNumberWithoutDot
	"self new currentMajorVersionNumberWithoutDot"
	^ self class currentMajorVersionNumber asString copyWithout: $.! !

!Loader methodsFor: 'compute' stamp: 'StephaneDucasse 9/10/2010 17:42'!
currentVersionsToBeSaved
	"self new currentVersionsToBeSaved"
	
	^ self allCurrentVersions reject: [ :each |
		self packagesNotToSavePatternNames
			anySatisfy: [ :p | p match: each ] ]! !

!Loader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 9/10/2010 17:51'!
diffPackages
	"return a list of packages that are new. They can be dirty or not."
	"self new diffPackages"
	 
	| diff |
	diff := Set new.
	self currentVersionsToBeSaved do: [:each |
		(PackagesBeforeLastLoad includes: each) ifFalse: [diff add: each]].
	^ diff
	! !

!Loader methodsFor: 'initialize' stamp: 'StephaneDucasse 9/10/2010 17:49'!
initialize
	super initialize.
	PackagesBeforeLastLoad ifNil: [ PackagesBeforeLastLoad := Set new ]! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
markPackagesBeforeNewCodeIsLoaded
	"Use this method to keep a log of all the packages that were loaded before loading new code. This will help the system to perform a diff and know after what to publish."
	
	"self new markPackagesBeforeNewCodeIsLoaded"
	
	PackagesBeforeLastLoad := self currentVersionsToBeSaved! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:40'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
		).! !

!Loader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:51'!
resetPackagesBeforeLastLoad
	PackagesBeforeLastLoad := Set new! !

Loader subclass: #ScriptLoader
	instanceVariableNames: 'repository inboxRepository repository39 repositorySqueakTrunk repository310 repositoryTaskForces repositoryMC repositoryTreated'
	classVariableNames: 'CheckImageInSyncWithUpdate CurrentMajorVersionNumber CurrentScriptVersionNumber CurrentUpdateVersionNumber CurrentlyIntegratingChanges LogStream Repository'
	poolDictionaries: 'TextConstants'
	category: 'ScriptLoader13'!

!ScriptLoader commentStamp: 'StephaneDucasse 5/26/2010 20:49' prior: 0!
Pharo Process Description


---
Here is the pharo process.

General points
-----------------------
An enhancement
	- should be added to the bug tracker
	- announced to the mailing-list
	- asked for feedback 
	- results should be added to the BT entry

Fixed tag means ready for integration
Closed tag means integrated

A bug detected
	- discuss via the mailing-list
	- should be added to the bug tracker
	- fix are considered as enh (see point above)

When a fix is fixed it should be either post as cs to the BT entry or in the PharoInbox
as a Slice (a slice is an emtpy package that has as requirement other package composing the fix).

We have three projects:
	Pharo
	PharoInbox
	PharoTreatedInbox

A fix goes either from inbox to treatedInbox or to Pharo.
If a fix does not work it is moved to the TreatedInbox.
If a fix works it is integrated as follow - it will be moved from the Inbox to the TreatedInbox
and integrated and published in the Pharo project

To help browsing multiple repositories:

ScriptLoader new addExtraRepositories


+++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
Now the integration works in 4 main steps which can be steered by the following expression
ScriptLoader releaseMenu
or via the menu that can be shown/hidden using 
	ScriptLoader showIntegrationMenu
	ScriptLoader hideIntegrationMenu


1.) Start up a recent and clean image
	ScriptLoader new prepareNewUpdate
	
	This step will 
		- load the latest updates
		- load the latest ScriptLoader package from the Pharo repository.
		Indeed when we work on improving the ScriptLoader it may not be published in the update stream. 
		New versions can be available on the server but not part of the latest updates.
		Therefore the process always loads the latest version of scriptloader from the pharo repository.
		This point is important because when an integration failed, you have to check and optionally 
		remove the scriptloader package from the pharo repository.
		
		- check that the update.list (which contains the cs to load the packages) is in sync
		with the image current version. You have to download the latest version using a script like this one.
		Pay attention to update it so that it reflects the right version (ie 1.0, 1.1, 1.2...)
		     scp -p LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/updates.list .
		- snapshot the package version to detect dirty or changed but non dirty packages.

2.) Apply changes

	ScriptLoader new doneApplyingChanges
	
	This step will 
		- create an update method with can trigger the load of the packages and some pre/post actions
		- create a script method with describes all the package versions and it used by the update methods
		- save all the packages that are different (except some filtered packages)	
		into a local folder named package-to-be-tested.
		ScriptLoader, SLICE*.... and a couple of other packages are not considered to be included in the script method
			(check method packagesNotToSavePatternNames)
		

3.) Verify changes
	==> in a ***new*** image (in the current folder) execute:
	ScriptLoader new verifyNewUpdate

	This step will 
		- load in any order (so may break) the package previously saved
		in the packages to be tested.
		- this step is important because you may get simple changes with unexpected side effects and that 
		may break the load.
		

4.) If there are problems go to 2.) to fix them, else:
	ScriptLoader new publishChanges

	This step will
		- generate a new cs file whose purpose is to load the given version of the scriptloader and trigger the 
		correct update method.
		- add the name of the cs file to the end of the updates.list file local to the disc
		- copy all the package from the local directory to the Pharo
		
	After the updates.list and the cs file should be manually uploaded to the ftp (see below) 
	   scp "$1" LOGIN@scm.gforge.inria.fr:/home/groups/pharo/htdocs/updates/pharo1.1/
	

5) in case of problems.
Think that if you pass the step 4 you may have a scriptLoader version that got published and that is reloaded 
during the first step.



CurrentMajorVersionNumber should contains a string '1.0', '1.1'....
This string will determine on which folder on the server the updates.list should be loaded.
	i.e., updates/pharo1.0, updates/pharo1.1 ....

--- Not to forget ---
To change the release stream
add a new method for each releaseStream
	ScriptLoader toPharoOne
	ScriptLoader toPharoOneDotOne
!

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 9/10/2010 17:28'!
checkImageInSyncWithUpdate
	"most of the time you want to make sure that your image is in sync with the latest item of the update.list
	but in some cases you do not to get forced to have this behavior."
	
	^ CheckImageInSyncWithUpdate ifNil: [CheckImageInSyncWithUpdate := true]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 6/12/2010 08:47'!
checkImageInSyncWithUpdate: aBoolean

	CheckImageInSyncWithUpdate := aBoolean! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:15'!
currentMajorVersionNumber

	^ CurrentMajorVersionNumber ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:12'!
currentMajorVersionNumber: aNumber

	CurrentMajorVersionNumber := aNumber! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:06'!
currentlyIntegratingChanges

	CurrentlyIntegratingChanges isNil ifTrue: [self hideIntegrationMenu].
	^ CurrentlyIntegratingChanges! !

!ScriptLoader class methodsFor: 'private' stamp: 'adrian_lienhard 3/16/2009 21:32'!
defaultMCWaitingFolder
	"self defaultMCWaitingFolder" 
	
	^ MCDirectoryRepository new directory: self waitingCacheFolder! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			(self new)
				installGofer;
				gofer ]! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
hideIntegrationMenu

	CurrentlyIntegratingChanges := false.! !

!ScriptLoader class methodsFor: 'loadscripts' stamp: 'StephaneDucasse 9/10/2010 17:24'!
initialize
	self flag: #shouldRemoveNumber.
	CurrentMajorVersionNumber :=  1.2! !

!ScriptLoader class methodsFor: 'private' stamp: 'al 11/1/2008 20:03'!
loadLatestPackage: aString from: aPath
	| repository |
	
	repository := MCHttpRepository
		location: aPath
		user:  ''
		password: ''.
	self loadLatestPackage: aString fromRepository: repository! !

!ScriptLoader class methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
loadLatestPackage: aString fromRepository: aRepository
	| versionsBlock versions tries |
	
	versionsBlock := [ (aRepository allVersionNames select: [ :each |
		each beginsWith: aString ])
		asSortedCollection: [ :a :b |
			(a copyAfterLast: $.) asNumber <= (b copyAfterLast: $.) asNumber]].
	versions := versionsBlock value.
	tries := 0.
	[ versions isEmpty and: [ tries < 3 ] ] whileTrue: [
		versions := versionsBlock value.
		tries := tries + 1 ].
	versions isEmpty ifTrue: [ self error: 'problems when accessing squeaksource' ].
	
	aRepository versionReaderForFileNamed: (versions last , '.mcz') do: [:reader | | version |
		version := reader version.
		version load.
		version workingCopy repositoryGroup addRepository: aRepository]! !

!ScriptLoader class methodsFor: 'private' stamp: 'AlexandreBergel 10/23/2008 15:31'!
loadLatestPackage: aString fromSqueaksource: aDirectoryName
	" self loadLatestPackage: 'ScriptLoader' fromSqueaksource: 'Pharo' "

	self loadLatestPackage: aString from: 'http://www.squeaksource.com/', aDirectoryName
	! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
menuCommandOn: aBuilder 
	<worldMenu> 
	
	(aBuilder item: #'Integrator Menu')
		order: 1.5;
		precondition: [self currentlyIntegratingChanges];
		parent: #System;
		icon: self theme smallAuthoringToolsIcon;
		action: [ScriptLoader releaseMenu]! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 11/9/2010 18:39'!
releaseMenu
	"self releaseMenu"
	|symbol|
	symbol := UIManager default
		chooseFrom: #('1- Prepare new update'
		                        '2- Save new image for testing (optional)'
						'3- Freeze changes: packages will be saved (required)'
						'4- Verify new update (open the mother image in the same folder) (optional)'
						'5- Publish changes')
		values: #(prepareNewUpdate saveImageForRunningTests doneApplyingChanges verifyNewUpdate publishChanges).
	symbol ifNotNil: [ScriptLoader new perform: symbol]! !

!ScriptLoader class methodsFor: 'public' stamp: 'adrian-lienhard 6/6/2009 11:46'!
resetLogStream
	LogStream := nil! !

!ScriptLoader class methodsFor: 'menu' stamp: 'StephaneDucasse 5/14/2010 22:03'!
showIntegrationMenu

	CurrentlyIntegratingChanges := true.! !

!ScriptLoader class methodsFor: 'menu' stamp: 'FernandoOlivero 4/12/2011 10:14'!
theme
	^ UITheme current ! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOne

	self currentMajorVersionNumber: 1.0! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 10/18/2009 17:14'!
toPharoOneDotOne

	self currentMajorVersionNumber: 1.1! !

!ScriptLoader class methodsFor: 'public' stamp: 'MarcusDenker 1/18/2011 16:56'!
toPharoOneDotThree

	self currentMajorVersionNumber: 1.3! !

!ScriptLoader class methodsFor: 'public' stamp: 'StephaneDucasse 5/14/2010 22:21'!
toPharoOneDotTwo

	self currentMajorVersionNumber: 1.2! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 2/25/2010 18:22'!
CSForLastUpdate: aString
	"ScriptLoader new CSForLastUpdate: 'cleanUpMethods'"
	
	| str updateNumber filename|
	updateNumber := self getLatestUpdateNumber.
	filename := updateNumber asString, '-Pha-', aString, '.cs'.
	FileDirectory default 
		forceNewFileNamed:  filename
		do: [ :stream | 
					self 
						generateCS: self latestScriptLoaderPackageIdentificationString
						fromUpdate: updateNumber on: stream].
	^ filename! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2010 22:31'!
CSForLastUpdateAndPatchUpdatesList: aString
	"ScriptLoader new CSForLastUpdateAndPatchUpdatesList: 'cleanUpMethods'"
	| filename |
	filename := self CSForLastUpdate: aString.
	self updateUpdatesList: aString.
	^ filename ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addExtraRepositories
	
	"self new addExtraRepositories"
	
	self addRepository39ToAllPackages.
	self addRepository310ToAllPackages.
	self addRepositoryTaskForcesToAllPackages.
	self addRepositorySqueakTrunkToAllPackages.
	self addRepositoryMCToAllPackages.
	self addRepositoryTreatedToAllPackages.! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 21:51'!
addHomeRepositoryToAllPackages
	"self new addHomeRepositoryToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			addRepository: self repositoryTreated ].
		
	MCRepositoryGroup default
			 addRepository: self repository;
			 addRepository: self inboxRepository;
			 addRepository: self repositoryTreated.
	
		
	
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 17:40'!
addHomeRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 10/18/2009 16:11'!
addPackage: aString
	"to be tested" 
	
	| workingCopy |
	PackageInfo registerPackageName: aString.
	workingCopy := MCWorkingCopy forPackage: (MCPackage new name: aString)! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/13/2009 15:48'!
addRepository310ToAllPackages
	"self new addRepository310ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository310
			].
	
	! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/6/2009 17:38'!
addRepository39ToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepository39ToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repository39
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/14/2009 10:31'!
addRepositoryMCToAllPackages
	
	"self new addRepositoryMCToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryMC
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/10/2009 20:47'!
addRepositorySqueakTrunkToAllPackages
	"self new removeAllRepositories: #('http://www.squeaksource.com/Sapphire/' 			'http://www.squeaksource.com/SapphireInbox/')"
	"self new addRepositorySqueakTrunkToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositorySqueakTrunk
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/13/2009 15:59'!
addRepositoryTaskForcesToAllPackages
	"self new addRepositoryTaskForcesToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTaskForces
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 10/31/2005 18:01'!
addRepositoryToPackageNamed: aString
	
	|pa|
	pa := MCPackage named: aString.
	pa workingCopy repositoryGroup addRepository: self repository.
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 9/26/2009 07:46'!
addRepositoryTreatedToAllPackages
	"self new addRepositoryTreatedToAllPackages"
	
	MCWorkingCopy allManagers do: [:each | 
		each repositoryGroup
			 addRepository: self repositoryTreated
			].
	
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentDirtyPackages
	"ScriptLoader new allCurrentDirtyPackages"
	"return all the current dirty packages even the ones that we do not want to save"

	
	^  self allCurrentPackages select: [:each | each needsSaving].

	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 6/30/2008 15:15'!
allCurrentPackages
	"ScriptLoader new allCurrentPackages" 
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 9/10/2010 17:26'!
announceOnMailingList
	"
	self new announceOnMailingList"
	|title|
	title := '[update ', self currentMajorVersionNumber asString , '] #', self currentUpdateVersionNumber asString.
UIManager default
	edit: title, String cr, self currentUpdateVersionNumber asString, '
-----

', self commentForCurrentUpdate
	label: title.! !

!ScriptLoader methodsFor: 'private' stamp: 'nice 1/5/2010 15:59'!
buildConfigurationMapFor: packageNames

	| configurationMap |
	configurationMap := MCConfiguration new.
	configurationMap repositories
		add: self repository;
		add: self inboxRepository.

	packageNames do: [:packageName | | version depArray |
		version := self loadVersionFromFileNamed: packageName.
		depArray := { version package name. version info name. version info id asString. }.
		configurationMap dependencies add: (MCConfiguration dependencyFromArray: depArray)].
	^configurationMap! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 1/31/2011 22:23'!
checkImageIsUptodate

	| stream last number |
	self class checkImageInSyncWithUpdate 
		ifFalse: [^ true].	
	stream := FileDirectory default oldFileNamed: self updatesListFileName.
	stream contents linesDo: [ :each | last := each ].
	stream close.
	last isNil 
		ifTrue: [^ false]. "in case the file is empty"
	 (last copyUpTo: $-) isAllDigits
		ifFalse: [^ true].  			"for cases where we have #Pharo1.1rc1 starting the line"
	number := (last copyUpTo: $-) asNumber.
	^ number = self getLatestUpdateNumber.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 11/13/2010 22:31'!
cleanRepositories
	"self new cleanRepositories"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllRepositories.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 4/16/2011 19:34'!
cleanUpForProduction
	"self new cleanUpForProduction"
	
	| oldDicts newDicts |
	
	"trim MC ancestory information"
	MCVersionInfo allInstances do: [ :each | each instVarNamed: 'ancestors' put: nil ].	

	"delete logo"	
	LogoImageMorph default: nil.

	"delete ScriptLoader log"
	ScriptLoader resetLogStream.

	Smalltalk globals at: #SUnitUnloader ifPresent:[ :unloader | unloader new unloadAll  ].
	(MCPackage named: 'HelpSystem-Core') unload.
	(MCPackage named: 'Deprecated12') unload.
	(MCPackage named: 'Deprecated13') unload.
	(MCPackage named: 'SimpleMorphic') unload.
	
	"shrink method dictionaries."
	Smalltalk garbageCollect.
	oldDicts := MethodDictionary allInstances.
	newDicts := Array new: oldDicts size.
	oldDicts withIndexDo: [ :d :index | newDicts at: index put: d rehashWithoutBecome ].
	oldDicts elementsExchangeIdentityWith: newDicts.
	oldDicts := newDicts := nil.
	
	self removeDejaVuFonts.
	(MCPackage named: 'Graphics-Resources') unload.
	
	(MCPackage named: 'HostMenus') unload.
	
	self cleanUpForRelease.
	(MCPackage named: self theScriptLoaderPackageName) unload.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	RecentMessageList cleanUp.
	Smalltalk garbageCollect
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 4/19/2011 17:04'!
cleanUpForRelease
	"self new cleanUpForRelease"

	Author fullName: 'Mr.Cleaner'.
	self cleanUpPackageOrganizer.
	self cleanUpMethods.
	Smalltalk cleanUp: true except: #() confirming: false.
	FreeTypeCache clearCurrent.
	ImageMorph classPool at: #DefaultForm put: (Form extent: 1 @ 1 depth: 1).
	Behavior flushObsoleteSubclasses.
	MethodChangeRecord allInstancesDo: [ :x | x noteNewMethod: nil ].
	World cleanseOtherworldlySteppers.
	Smalltalk organization removeEmptyCategories.
	SystemBrowser removeObsolete.
	Smalltalk globals
		at: #TTFontDescription
		ifPresent: [ :c | 
			c
				clearDefault;
				clearDescriptions ].
	ExternalDropHandler resetRegisteredHandlers.
	Undeclared removeUnreferencedKeys.
	Smalltalk globals flushClassNameCache.
	NaturalLanguageTranslator classPool at: #AllKnownPhrases put: nil.
	FreeTypeFontProvider current initialize.
	SystemNavigation default
		allObjectsDo: [ :each | 
			(each respondsTo: #releaseCachedState)
				ifTrue: [ each releaseCachedState ] ].
	3 timesRepeat: [ 
		Smalltalk garbageCollect.
		Symbol compactSymbolTable ].
	HashedCollection rehashAll.
	
	"Remove empty categories, which are not in MC packages, because MC does
	not do this (this script does not make packages dirty)"
	Smalltalk organization removeEmptyCategories.
	Smalltalk
		allClassesAndTraitsDo: [ :class |
			[ :each |
				each
					removeEmptyCategories;
					sortCategories ]
						value: class organization;
						value: class class organization ].
	PackageOrganizer default packages
		do: [ :each | each methods ifEmpty: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'.
	Smalltalk organization sortCategories.
	ChangeSet removeChangeSetsNamedSuchThat: [ :each | true ].
	ChangeSet resetCurrentToNewUnnamedChangeSet.
	Smalltalk garbageCollect.
	Author reset! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 6/5/2010 11:12'!
cleanUpMethods
	"Make sure that all methods in use are restarted"
	"ScriptLoader new cleanUpMethods"

	WeakArray restartFinalizationProcess.
	MethodChangeRecord allInstancesDo: [:x | x noteNewMethod: nil].
	WorldState allInstancesDo: [ :ws | ws convertAlarms; convertStepList; resetWorldMenu].
	WorldState allInstancesDo: [ :ws | ws instVarNamed: 'menuBuilder' put: nil ].
	ExternalDropHandler initialize.
	ScrollBar initializeImagesCache.
	GradientFillStyle initPixelRampCache.
	ProcessBrowser initialize.
	Smalltalk garbageCollect.
	Delay startTimerEventLoop! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'StephaneDucasse 12/5/2009 11:19'!
cleanUpPackageOrganizer

	PackageOrganizer default packages
		do: [ :each | 
			each methods isEmpty
				ifTrue: [ PackageOrganizer default unregisterPackage: each ] ]
		displayingProgress: 'Cleaning Packages'! !

!ScriptLoader methodsFor: 'public' stamp: 'MarcusDenker 4/26/2011 22:50'!
commentForCurrentUpdate
 ^ 'Issue 4094:	Object>>chooseUniqueClassName can be removed
Issue 2177:	Generalize stream protocol #readInto:startingAt:count:'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 14:36'!
compileNewUpdateMethod
	"Use me to create a new update method with the next update number"
	"self new compileNewUpdateMethod"
	

	self class compile: 
		(self newGenerateNewUpdateMethod)
		classified: 'pharo - updates'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 4/4/2010 13:26'!
compileScriptMethodWithCurrentPackages: aNumber 
	"ScriptLoader new compileScriptMethodWithCurrentPackages: 9999"
	
	self class compile: 
		(self newGenerateScriptTemplateWithCurrentPackages: aNumber)
		classified: 'pharo - scripts'! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
copyPackagesFromWaitingFolderToHomeRepository
	"self defaultMCWaitingFolder allFileNames"
	"self new copyPackageFromWaitingFolderToHomeRepository"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		self repository storeVersion: version]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'al 11/1/2008 19:49'!
currentPackages
	"self new currentPackages" 
	
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies reject: [:each |
		self packagesNotToSavePatternNames
			anySatisfy: [:p | p match: each package name]].
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:08'!
currentScriptVersionNumber
	^ CurrentScriptVersionNumber! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 9/8/2009 14:41'!
currentUpdateVersionNumber
	^ CurrentUpdateVersionNumber ifNil: [SystemVersion current highestUpdate]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 5/29/2006 20:52'!
currentVersions
	"ScriptLoader new currentVersions"
	
	| copies |
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	^ copies collect:
		[:ea |  ea ancestry ancestorString ]! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:46'!
deletePackage: aString

	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	MCWorkingCopy registry removeKey: toRemove package.! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 5/3/2010 22:54'!
doneApplyingChanges
	| comment commentQuoted st |
	SmalltalkImage current saveSession.
		"now you can reopen prior to publishing to fix :)"
	self saveAsNewImageWithCurrentReleaseNameToPublish.
	
	comment := UIManager default
		multiLineRequest: 'Comment for this update.'
		centerAt: Sensor cursorPoint
		initialAnswer: self commentForCurrentUpdate
		answerHeight: 200.
	comment ifNil: [^ self].
	
	commentQuoted := comment copyReplaceAll: (String with: $') with: (String with: $' with: $').
	st := String new writeStream.
	st nextPutAll: 'commentForCurrentUpdate'; cr.
	st nextPutAll: ' ^ '.
	st nextPut: $'.
	st nextPutAll: commentQuoted.
	st nextPut: $'.
	self class
		compile: (st contents)
		classified: 'public'.

	self class waitingCacheFolder deleteLocalFiles.
	self saveChangedPackagesIntoWaitingFolder.
	self generateScriptAndUpdateMethodForNewVersion.
	self saveLatestScriptLoaderToWaitingFolder.
	
	self inform: 'Update prepared and ready to be verified.'! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'MarcusDenker 8/15/2010 12:33'!
fixObsoleteReferences
	"self new fixObsoleteReferences"
	CompiledMethod allInstances
		do: [ :method | 
			| obsoleteBindings |
			obsoleteBindings := method literals
				select: [ :literal | literal isVariableBinding 
									and: [ literal value isBehavior and: [ literal value isObsolete ]] ].
			obsoleteBindings
				do: [ :binding | 
					| realClass obsName realName |
					obsName := binding value name.
					Transcript
						show: obsName;
						cr.
					realName := obsName copyReplaceAll: 'AnObsolete' with: ''.
					realClass := Smalltalk globals at: realName asSymbol ifAbsent: [ UndefinedObject ].
					binding key: binding key value: realClass ] ].
	Behavior flushObsoleteSubclasses.
	Smalltalk
		garbageCollect;
		garbageCollect.
	SystemNavigation default obsoleteBehaviors size > 0
		ifTrue: [ SystemNavigation default obsoleteBehaviors inspect ]! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'AdrianLienhard 3/14/2010 12:44'!
flushCaches

	MCFileBasedRepository flushAllCaches.
	MCDefinition clearInstances.
	Smalltalk garbageCollect.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 8/14/2008 16:06'!
generateCS: packageInfo fromUpdate: updateNumber on: st
	
	st nextPutAll:
'"Postscript:
Leave the line above, and replace the rest of this comment by a useful one.
Executable statements should follow this comment, and should
be separated by periods, with no exclamation points (!!!!).
Be sure to put any further comments in double-quotes, like this one."

|repository|
repository := MCHttpRepository
                location: ''http://www.squeaksource.com/Pharo/''
                user: ''''
                password: ''''.
(repository loadVersionFromFileNamed:' .
	st nextPut: $' ; nextPutAll: packageInfo, '.mcz'') load.'; cr.
	st nextPutAll: 'ScriptLoader new update', (updateNumber) asString; nextPutAll: '.' ; cr.
	st nextPutAll: '!!'.
	^ st contents
! !

!ScriptLoader methodsFor: 'utils' stamp: 'stephane.ducasse 7/4/2009 12:27'!
generateCompleteFixList
	"generateCompleteFixList"
	| stream |
	stream := (FileStream newFileNamed: 'changes-log.txt').
	[ stream nextPutAll: ScriptLoader new logStream contents ] ensure: [ stream close ]! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'DamienCassou 8/30/2009 14:48'!
generateNewUpdateMethod
	"ScriptLoader new generateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, '.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'adrianLienhard 11/1/2008 23:05'!
generateScriptAndUpdateMethodForNewVersion
	"Use me to generate the script and update method"
	"self new generateScriptAndUpdateMethodForNewVersion"
	
	self compileScriptMethodWithCurrentPackages: self currentScriptVersionNumber.
	self compileNewUpdateMethod.! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 14:41'!
generateScriptTemplateWithAllCurrentPackages
	"ScriptLoader new generateScriptTemplateWithAllCurrentPackages"
	
	| str |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'scriptXXX' ; cr ; cr ; tab.
	str nextPutAll: '| names|'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	self currentVersionsToBeSaved do: 
		[:each |
			str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'stephane.ducasse 3/21/2009 18:07'!
generateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '| names |'; cr.
	str nextPutAll: 'names := '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr.

	self loadTogether: names merge: false.'.
	^ str contents! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'al 11/1/2008 18:15'!
getLatestScriptNumber
	"self new getLatestScriptNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'script*' match: each ].
	upfroms := upfroms collect: [:each | (each asString allButFirst: 6)].
	upfroms := upfroms reject: [:each | '*Log*' match: each ].
	upfroms := upfroms reject: [:each | '*XXX*' match: each ].
	upfroms := upfroms collect: [:each | each asNumber].
	^ upfroms asSortedCollection last
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 10/17/2009 12:33'!
getLatestUpdateNumber
	"self new getLatestUpdateNumber"
	
	| upfroms |
	upfroms := self class selectors select: [:each | 'update*' match: each ].
	upfroms := upfroms collect: [:each | [(each asString last: 5) asNumber] on: Error do: [0]].
	^ upfroms asSortedCollection last! !

!ScriptLoader methodsFor: 'accessing' stamp: 'lr 3/14/2010 21:13'!
gofer
	^ Smalltalk globals
		at: #Gofer
		ifAbsent: [ 
			self
				installGofer;
				gofer ]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'CarloTeixeira 8/11/2010 00:37'!
inboxRepository
	^ inboxRepository ifNil: [inboxRepository :=  MCHttpRepository inboxRepository]
	! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 7/10/2009 18:07'!
installGofer
	"self new installGofer"
	
	self class loadLatestPackage: 'Gofer' from: 'http://source.lukas-renggli.ch/flair'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 3/15/2008 14:46'!
installRepository: aString for: packageName

	(MCWorkingCopy allManagers select: [:each | each package name = packageName])
		first repositoryGroup
		addRepository: (MCHttpRepository new location: aString ; user: '' ; password: '')
		! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'alain.plantec 2/6/2009 15:49'!
installVersionInfo
	"self new installVersionInfo"

	| highestUpdate newVersion |
	highestUpdate := SystemVersion current highestUpdate.
	(self confirm: 'Reset highest update (' , highestUpdate printString , ')?')
		ifTrue: [SystemVersion current highestUpdate: 0].

	newVersion := UIManager default request: 'New version designation:' translated initialAnswer: '3.9' , highestUpdate printString. 
	SystemVersion newVersion: newVersion.
	
! !

!ScriptLoader methodsFor: 'utils' stamp: 'lr 3/14/2010 21:13'!
installingInstaller
	"self new installingInstaller"

	| mc files fileToLoad version |
	mc := Smalltalk globals
		at: #MCHttpRepository
		ifPresent: [ :repoClass | repoClass location: 'www.squeaksource.com/Installer' user: 'squeak' password: 'squeak' ].
	files := mc readableFileNames
		asSortedCollection: [ :a :b | 
			[ (a findBetweenSubStrs: #($.)) allButLast last asInteger > (b findBetweenSubStrs: #($.)) allButLast last asInteger ]
				on: Error
				do: [ :ex | false ] ].
	fileToLoad := files detect: [ :aFile | aFile beginsWith: 'Installer-Core' ] ifNone: [ nil ].
	version := mc versionFromFileNamed: fileToLoad.
	version workingCopy repositoryGroup addRepository: mc.
	mc creationTemplate: mc asCreationTemplate.
	version load.
	^ Smalltalk globals at: #Installer! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'stephane.ducasse 8/14/2008 16:03'!
latestScriptLoaderPackageIdentificationString
	"ScriptLoader new latestScriptLoaderPackageIdentificationString"
	
	^  self allCurrentVersions detect: [:each | 'ScriptLoader*' match: each ]
	! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'Jb 10/23/2010 12:14'!
launchUpdate

	UpdateStreamer new updateFromServer! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:06'!
loadLatestScriptloader
	"self new loadLatestScriptloader"
	
	self class 
		loadLatestPackage: 'ScriptLoader', self currentMajorVersionNumberWithoutDot 
		fromSqueaksource: 'Pharo' 
	

! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 2/10/2011 20:29'!
loadLatestUpdateList
	"fetch the latest version of the update.list on the server"
	
	| listToUse lastUpdate |
	listToUse := (HTTPClient httpGet: UpdateStreamer new updateFolderURL , self updatesListFileName) contents.
				
	listToUse linesDo: [:each | lastUpdate := each].
	(lastUpdate beginsWith: self getLatestUpdateNumber asString)
		 ifTrue: ["Write this file as our current updates.list"
			FileDirectory default
				forceNewFileNamed: self updatesListFileName
				do: [:stream | stream nextPutAll: listToUse]]
		ifFalse: [ 
			self inform: 'Image update version did not match automatically fetched  update.list!!  
			Proceed after downloading using the script ./getUpdatesList instead' ].
	! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'nice 1/5/2010 15:59'!
loadOneAfterTheOther: aCollection merge: aBoolean
	
	(self newerVersionsIn: aCollection)
		do: [:fn | | loader |
			loader := aBoolean
				ifTrue: [ MCVersionMerger new ]
				ifFalse: [ MCVersionLoader new].
			loader addVersion: (self repository loadVersionFromFileNamed: fn).
			aBoolean
				ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
							request merger conflicts isEmpty
								ifTrue: [request resume: true]
								ifFalse: [request pass]]]
				ifFalse: [loader load]]
  	  	displayingProgress: 'Loading versions...'.
	

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'adrian_lienhard 2/21/2009 13:40'!
loadOneAfterTheOther: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadOneAfterTheOther: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			self loadOneAfterTheOther: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
loadPackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles do: [:name | | version |
		version := self class defaultMCWaitingFolder versionFromFileNamed: name.
		version load]! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'michael.rueger 1/13/2009 15:26'!
loadTogether: aCollection merge: aBoolean
	| loader |
	loader := aBoolean
		ifTrue: [ MCVersionMerger new ]
		ifFalse: [ MCVersionLoader new].
	(self newerVersionsIn: aCollection)
		do: [:fn | loader addVersion: (self loadVersionFromFileNamed: fn)]
  	  	displayingProgress: 'Adding versions...'.
	aBoolean
		ifTrue: [[loader merge] on: MCMergeResolutionRequest do: [:request |
					request merger conflicts isEmpty
						ifTrue: [request resume: true]
						ifFalse: [request pass]]]
		ifFalse: [loader hasVersions ifTrue: [loader load]]

! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 5/10/2008 12:41'!
loadTogether: aCollection merge: aBoolean silently: anotherBoolean
	anotherBoolean
		ifTrue: [ 
			[ self loadTogether: aCollection merge: aBoolean ]
				on: ProgressInitiationException do: [:e | e sendNotificationsTo: [ :min :max :curr ] ] ]
		ifFalse: [
			 self loadTogether: aCollection merge: aBoolean ]! !

!ScriptLoader methodsFor: 'private' stamp: 'michael.rueger 1/13/2009 15:25'!
loadVersionFromFileNamed: fn
	| version |
	version := self repository loadVersionFromFileNamed: fn.
	^version
		ifNil: [self inboxRepository loadVersionFromFileNamed: fn]! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 4/4/2008 14:47'!
log: aString

	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/15/2008 18:30'!
logContents

	^ self logStream contents! !

!ScriptLoader methodsFor: 'log' stamp: 'adrian_lienhard 3/16/2009 21:30'!
logStream
	^ LogStream ifNil: [
		LogStream := ReadWriteStream on: (String new: 1000)]! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'nice 1/5/2010 15:59'!
mergePackageFromWaitingFolder
	"self defaultMCWaitingFolder allFileNames"
	"self new loadPackageFromWaitingFolder"
	
	
	self waitingFolderMCZFiles
		do: [ :name | | version |
			version := self class defaultMCWaitingFolder  versionFromFileNamed: name.
			version merge.
			]! !

!ScriptLoader methodsFor: 'accessing' stamp: 'AdrianLienhard 6/5/2010 11:08'!
metacelloRepository
	^ (MCHttpRepository 
		location: 'http://www.squeaksource.com/MetacelloRepository'
		user: ''
		password: '')
	! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:35'!
newGenerateNewUpdateMethod
	"ScriptLoader new newGenerateNewUpdateMethod"
	
	| str mthName preamble postscript |
	str := ReadWriteStream on: (String new: 1000).
	mthName := 'update', self currentUpdateVersionNumber asString.
	str nextPutAll: mthName ; cr  ; tab.
	str nextPutAll: '"self new ', mthName, '"'; crtab. 
	preamble := UIManager default 
		multiLineRequest: 'Preamble expression'
		centerAt: Sensor cursorPoint
		initialAnswer: ''
		answerHeight: 100.
	preamble isEmptyOrNil ifFalse: [str nextPutAll: preamble; ensureEndsWith: $.; crtab].

	str nextPutAll: 'self withUpdateLog: ' ; nextPut: $'; nextPutAll: self commentForCurrentUpdate ; nextPut: $'; nextPut: $. .
	str crtab.
	str nextPutAll: 'self loadTogether: '.
	str nextPutAll: 'self script' , self currentScriptVersionNumber asString, ' merge: false.'.
	str crtab.
	postscript := UIManager default
					multiLineRequest: 'Postscript expression'
					centerAt: Sensor cursorPoint
					initialAnswer: ''
					answerHeight: 100. 
	postscript isEmptyOrNil ifFalse: [str nextPutAll: postscript; ensureEndsWith: $.; crtab].
	
	str nextPutAll: 'self flushCaches.'; cr.
	
	^ str contents! !

!ScriptLoader methodsFor: 'new script-update format' stamp: 'StephaneDucasse 4/4/2010 13:25'!
newGenerateScriptTemplateWithCurrentPackages: aNumber
	"ScriptLoader new generateScriptTemplateWithCurrentPackages"
	"this version change the script to only "
	
	| str withoutScriptLoader |
	str := ReadWriteStream on: (String new: 1000).
	str nextPutAll: 'script', aNumber asString ; cr ; cr ; tab.
	str nextPutAll: '^ '.
	str nextPut: $'.
	withoutScriptLoader := self currentVersionsToBeSaved.
	withoutScriptLoader
		do: [ :each | str nextPutAll: each ; nextPutAll: '.mcz']
		separatedBy: [str nextPut: Character cr].
	str nextPut: $'; nextPut: Character cr.
	str nextPutAll: 'findTokens: String lf , String cr'.
	^ str contents! !

!ScriptLoader methodsFor: 'load primitives' stamp: 'al 10/13/2005 21:44'!
newerVersionsIn: aCollection
	^aCollection reject: [:each |
		MCWorkingCopy allManagers anySatisfy: [:workingcopy |
			workingcopy ancestry ancestorString , '.mcz' = each]].! !

!ScriptLoader methodsFor: 'utils' stamp: 'sd 2/4/2008 16:09'!
openWindow: contents label: aLabel

	StringHolder new 
		contents: contents ;
		openLabel: aLabel! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 7/17/2010 13:35'!
packagesNotToSavePatternNames
	^ #(	'ScriptLoader*'
			'AST*'
			'*Refactoring*'
			'Metacello*'
			'SLICE*'
			'Slice*'
			'slice*'
			'*OB-*'
			'OmniBrowser*'
		).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 7/7/2010 23:23'!
prepareNewUpdate
	self launchUpdate.
	self loadLatestScriptloader.
	self markPackagesBeforeNewCodeIsLoaded.
	self checkImageIsUptodate ifFalse: [self loadLatestUpdateList].
	self checkImageIsUptodate ifFalse: [
		^ self inform: 'Your update.list and your image are not in sync!! Please use a fresh image and download the latest update.list and start over. May be you are doing a rollback and you should remove the bogus ScriptLoader version from the Pharo repository' ].
	self setUpdateAndScriptVersionNumbers.
	self saveAsNewImageWithCurrentReleaseName.
	self inform: 'The new version number is ' , self currentUpdateVersionNumber asString , '. Ready to apply changes now.', String cr, 'You are now running in image ', (FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName)).! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 1/31/2011 22:17'!
publishChanges
	| username password changescriptname changesetFilename str strings|
	(FileStream isAFileNamed: 'PharoPass.txt') 
		ifTrue: [ str := FileStream fileNamed:  'PharoPass.txt'. 
				strings := str contents substrings.
				username := strings first.
				password := strings second] 
		ifFalse: [ username := UIManager default request: 'Pharo repository login'.
			     password := UIManager default requestPassword: 'Pharo repository password'.].

	self setToRepositoriesPassword: password to: username.
	
	changescriptname := UIManager default request: 'Changeset name (no space)' initialAnswer: 'WhatAsChanged'.
	changesetFilename := self CSForLastUpdateAndPatchUpdatesList: changescriptname.
	self copyPackagesFromWaitingFolderToHomeRepository.
	self announceOnMailingList.
	self inform: 'All packages have been uploaded to the Pharo repository.
Remaining manual steps:
1) ./upFilesXX ',changesetFilename,'
2) ./upFilesXX updatesXX.list
3) Announce new update on mailing list'! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'StephaneDucasse 11/13/2010 22:30'!
removeAllHTTPRepositories: aColl
	"self new removeAllRepositories: 
			#('http://source.squeakfoundation.org/inbox/'
			 'http://source.squeakfoundation.org/39a/'
			 'http://source.squeakfoundation.org/Balloon/'
			 'http://source.squeakfoundation.org/Compression/'
			 'http://source.squeakfoundation.org/Graphics/'
			  'http://source.wiresong.ca/mc/')"
 
	
	MCWorkingCopy allManagers do: [:each | 
		aColl
			do: [:location | 
					each  repositoryGroup removeHTTPRepositoryLocationNamed: location]].
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 3/11/2010 20:22'!
removeAllRepositories
	"self new removeAllRepositories"
	
	MCWorkingCopy allManagers do: [:each |  each  repositoryGroup initialize].
	MCRepositoryGroup default initialize.
	! !

!ScriptLoader methodsFor: 'cleaning' stamp: 'BenjaminVanRyseghem 11/28/2010 19:02'!
removeDejaVuFonts
	"Note, you need to close all windows to make the Deja Vu fonts being GCed"

	StandardFonts setDefaultFonts: #(
		(defaultFont: 'Accuny' 10)
		(codeFont: 'Accuny' 10)
		(listFont: 'Accuny' 10)
		(menuFont: 'Accuny' 10)
		(windowTitleFont: 'Accuny' 10)
		(balloonFont: 'Accuny' 10)
		(buttonFont: 'Accuny' 10)).
	TextSharedInformation removeKey: 'Bitmap DejaVu Sans'! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:06'!
removeScriptMethods
	"self new removeScriptMethods"
	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - scripts') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 10/18/2009 16:04'!
removeUpdateMethods

	
	((ScriptLoader organization listAtCategoryNamed: 'pharo - updates') 
		asSortedCollection allButLast) 
			do: [:each | ScriptLoader removeSelector: each].! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:41'!
repository
	^ repository ifNil: [
		repository := MCHttpRepository new
			location:  'http://www.squeaksource.com/Pharo';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:48'!
repository310
	^ repository310 ifNil: [
		repository310 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/310';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repository39
	^ repository39 ifNil: [
		repository39 := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/39a';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'adrian_lienhard 3/16/2009 21:42'!
repository: aRepository
	repository := aRepository! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/14/2009 10:32'!
repositoryMC
	^ repositoryMC ifNil: [
		repositoryMC := MCHttpRepository new
			location:  'http://source.wiresong.ca/mc';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/10/2009 20:49'!
repositorySqueakTrunk
	^ repositorySqueakTrunk ifNil: [
		repositorySqueakTrunk := MCHttpRepository new
			location:  'http://source.squeakfoundation.org/trunk';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/13/2009 15:59'!
repositoryTaskForces
	^ repositoryTaskForces ifNil: [
		repositoryTaskForces := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTaskForces';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 9/26/2009 07:47'!
repositoryTreated
	^ repositoryTreated ifNil: [
		repositoryTreated := MCHttpRepository new
			location:  'http://www.squeaksource.com/PharoTreatedInbox';
			user: '';
			password: '']! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:30'!
saveAsImageAsTestImage
	"Now you can run tests and see and go back to the previous image
	and do that go and back.... then after you can decide to freeze"

	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-imageForTestsFor')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'DamienCassou 9/8/2009 14:42'!
saveAsNewImageWithCurrentReleaseName
	|name|
	name := FileDirectory default
				nextNameFor: ('releasePharo-',  self currentUpdateVersionNumber asString)
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/8/2010 22:31'!
saveAsNewImageWithCurrentReleaseNameToPublish
	"If the reload failed and you do not want to lose time reload all the cs and packages... you can now restart from the image saved now"
	
	|name|
	name := FileDirectory default
				nextNameFor: (self shortImageName, '-releasePharoToPublish')
				extension: FileDirectory imageSuffix.
	name isEmptyOrNil ifFalse: [SmalltalkImage current saveAs: name].! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'al 11/1/2008 18:33'!
saveChangedPackagesIntoWaitingFolder
	self currentChangedPackages do: [:each |
		self
			saveInToReloadCachePackage: each
			with: self commentForCurrentUpdate]! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'StephaneDucasse 11/9/2010 18:38'!
saveImageForRunningTests

	| comment commentQuoted st resuming |
	resuming := false.
	SmalltalkImage current saveSession
		ifFalse: [ resuming := true].
	resuming ifTrue: [
		self saveAsImageAsTestImage.
	
		self inform: 'Now you can use this image named ''Test'' to run the tests and come back to fix problems in the \ previous one and eventually freeze it by selecting the next step, in either one.' withCRs]! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'adrianLienhard 11/2/2008 00:31'!
saveInToReloadCachePackage: aWorkingCopy with: aMessageString
	self
		savePackage: aWorkingCopy
		in: self class defaultMCWaitingFolder
		with: aMessageString! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/28/2010 20:06'!
saveLatestScriptLoaderToHome
	"self new saveLatestScriptLoaderToHome"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader*' match: each  package name].
	self repository storeVersion: r first newVersion.! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 6/12/2010 13:31'!
saveLatestScriptLoaderToWaitingFolder
	"self new saveLatestScriptLoaderToWaitingFolder"

	| man r |
	man := MCWorkingCopy allManagers.
	r := man select: [:each | 'ScriptLoader', self currentMajorVersionNumberWithoutDot, '*' match: each  package name].
	self
		saveInToReloadCachePackage: r first
		with: self commentForCurrentUpdate! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'MarcusDenker 10/20/2009 11:28'!
savePackage: aWorkingCopy in: aRepository with: aMessageString
	" | sc |
	  sc := self new.
	  sc savePackage: (self new workingCopyFromPackageName: 'ScriptLoader11') 
		in: MCCacheRepository default
		with: 'this is test to automate dirty package saving in cache'"

	aRepository storeVersion: (aWorkingCopy 
		newVersionWithName: aWorkingCopy uniqueVersionName
		message: aMessageString)! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/19/2011 12:28'!
script0! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/19/2011 15:28'!
script1! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 15:20'!
script10

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.815.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.518.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/22/2011 13:41'!
script100

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.843.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.860.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.44.mcz
Polymorph-Widgets-StephaneDucasse.403.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.561.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/22/2011 14:19'!
script101

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.54.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.843.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.860.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.404.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.562.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/22/2011 17:50'!
script102

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.502.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.2.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.54.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.844.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.860.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.404.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.562.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/22/2011 20:56'!
script103

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.502.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.2.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.54.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.844.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.861.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.405.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.562.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/22/2011 21:48'!
script104

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.502.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.75.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.2.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.55.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.844.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.861.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.405.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.171.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.562.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/23/2011 15:18'!
script105

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.502.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.75.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.2.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.55.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.846.mcz
KernelTests-MarcusDenker.310.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.862.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.405.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.171.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.57.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.458.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.562.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/24/2011 15:37'!
script106

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.502.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.75.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.3.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.20.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.55.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.846.mcz
KernelTests-MarcusDenker.310.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.863.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.49.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.405.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.171.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.57.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.459.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.279.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.562.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/24/2011 17:08'!
script107

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.503.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-MarcusDenker.76.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.4.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.55.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.846.mcz
KernelTests-MarcusDenker.310.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.864.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.49.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.405.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.8.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.459.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.279.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.563.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/25/2011 12:35'!
script108

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-MarcusDenker.170.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.503.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-MarcusDenker.76.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.4.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.55.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.846.mcz
KernelTests-MarcusDenker.310.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.865.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.49.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.405.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.8.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.459.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.280.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.563.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/25/2011 18:23'!
script109

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-MarcusDenker.170.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.503.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.76.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.4.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.55.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.846.mcz
KernelTests-MarcusDenker.310.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.510.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.866.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.49.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.406.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.8.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.280.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.564.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 17:01'!
script11

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.815.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.521.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/25/2011 18:58'!
script110

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-MarcusDenker.170.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.503.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.76.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.4.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.849.mcz
KernelTests-StephaneDucasse.311.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.510.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.866.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.47.mcz
Polymorph-Widgets-StephaneDucasse.406.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.8.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.280.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.564.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/26/2011 09:52'!
script111

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.172.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.76.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.4.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.850.mcz
KernelTests-StephaneDucasse.311.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.511.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.867.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.48.mcz
Polymorph-Widgets-StephaneDucasse.407.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.8.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.123.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.280.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.564.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/28/2011 17:37'!
script112

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.172.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.5.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.22.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.850.mcz
KernelTests-MarcusDenker.313.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.511.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.868.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.48.mcz
Polymorph-Widgets-MarcusDenker.408.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.123.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.280.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.565.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/28/2011 18:19'!
script113

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.172.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.5.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.22.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.850.mcz
KernelTests-MarcusDenker.313.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.10.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.869.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.36.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.48.mcz
Polymorph-Widgets-MarcusDenker.409.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.172.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-StephaneDucasse.123.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.280.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.565.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/28/2011 21:56'!
script114

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.172.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.6.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.22.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.850.mcz
KernelTests-MarcusDenker.313.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.11.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.870.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-MarcusDenker.63.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.48.mcz
Polymorph-Widgets-MarcusDenker.410.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.173.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.566.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/29/2011 09:30'!
script115

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.6.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.22.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.851.mcz
KernelTests-MarcusDenker.313.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.11.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.871.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.48.mcz
Polymorph-Widgets-MarcusDenker.410.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.173.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-StephaneDucasse.19.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.16.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.567.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/29/2011 17:58'!
script116

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.6.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.22.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.851.mcz
KernelTests-MarcusDenker.313.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.11.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.871.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.48.mcz
Polymorph-Widgets-MarcusDenker.410.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.173.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-StephaneDucasse.19.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.16.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.152.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.570.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/29/2011 22:07'!
script117

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-StephaneDucasse.505.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.7.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.23.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.853.mcz
KernelTests-StephaneDucasse.314.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.11.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.872.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.411.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.173.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-StephaneDucasse.20.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.16.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.460.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.570.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/31/2011 12:35'!
script118

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.8.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-StephaneDucasse.23.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.853.mcz
KernelTests-StephaneDucasse.314.mcz
MenuRegistration-MarcusDenker.30.mcz
MimeConverter-MarcusDenker.11.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.873.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.412.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.173.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.21.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.16.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.461.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.112.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.571.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/31/2011 12:53'!
script119

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.9.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.855.mcz
KernelTests-MarcusDenker.316.mcz
MenuRegistration-MarcusDenker.30.mcz
MimeConverter-MarcusDenker.11.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.873.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.11.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.412.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.174.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.21.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Digital Signatures-StephaneDucasse.16.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-MarcusDenker.9.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.461.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.113.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.572.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 17:27'!
script12

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.815.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.505.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.522.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/31/2011 13:14'!
script120

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.9.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.199.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.855.mcz
KernelTests-MarcusDenker.316.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.874.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.11.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.412.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.174.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.21.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.461.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.573.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/31/2011 16:15'!
script121

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.9.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.199.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.855.mcz
KernelTests-MarcusDenker.316.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.512.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.874.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.11.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-StephaneDucasse.7.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.413.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.174.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.21.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.573.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 3/31/2011 21:12'!
script122

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.9.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.199.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.855.mcz
KernelTests-MarcusDenker.316.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.874.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-LaurentLaffont.414.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.174.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.21.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.573.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/31/2011 22:31'!
script123

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.9.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.199.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.857.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.875.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.415.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.174.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.21.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-StephaneDucasse.153.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.574.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/1/2011 13:29'!
script124

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.270.mcz
CompilerTests-MarcusDenker.77.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.11.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.199.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.52.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.858.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.90.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.876.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.415.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.174.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.23.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/1/2011 15:00'!
script125

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-MarcusDenker.272.mcz
CompilerTests-MarcusDenker.78.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.12.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeSubPixelAntiAliasing-MarcusDenker.24.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.53.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.858.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.877.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.415.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-MarcusDenker.175.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.23.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-MarcusDenker.3.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/1/2011 17:28'!
script126

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-MarcusDenker.276.mcz
CompilerTests-MarcusDenker.78.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.12.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.53.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.858.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.878.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.416.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.23.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/1/2011 17:41'!
script127

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-MarcusDenker.277.mcz
CompilerTests-MarcusDenker.79.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.12.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.53.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.858.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.878.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.416.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.23.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/1/2011 17:49'!
script128

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-MarcusDenker.278.mcz
CompilerTests-MarcusDenker.79.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.12.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.53.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.858.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.878.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.416.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.23.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-StephaneDucasse.12.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.124.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.462.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/2/2011 11:57'!
script129

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-MarcusDenker.278.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.54.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.858.mcz
KernelTests-StephaneDucasse.318.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.879.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.417.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.125.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.463.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 18:31'!
script13

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.816.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.506.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-StephaneDucasse.819.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.434.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.522.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 4/3/2011 22:42'!
script130

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.859.mcz
KernelTests-StephaneDucasse.319.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.880.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.418.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.125.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.464.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 4/5/2011 14:22'!
script131

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.859.mcz
KernelTests-StephaneDucasse.319.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-IgorStasenko.881.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.418.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.125.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-IgorStasenko.465.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/5/2011 16:39'!
script132

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.506.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.859.mcz
KernelTests-StephaneDucasse.319.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-LaurentLaffont.513.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.882.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.419.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-IgorStasenko.465.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/7/2011 13:03'!
script133

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.859.mcz
KernelTests-StephaneDucasse.319.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.514.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.883.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.419.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.466.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/7/2011 13:53'!
script134

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.860.mcz
KernelTests-StephaneDucasse.319.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.884.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.420.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.467.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/8/2011 15:12'!
script135

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.13.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.860.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.885.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.421.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40124.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.26.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.467.mcz
System-Text-MarcusDenker.155.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/8/2011 22:50'!
script136

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-StephaneDucasse.279.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.14.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.860.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.885.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.422.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40124.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.467.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/9/2011 22:26'!
script137

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.281.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.14.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.860.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.885.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.422.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40124.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.468.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/10/2011 17:03'!
script138

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.281.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.15.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.860.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.885.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.422.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40124.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.469.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/11/2011 13:33'!
script139

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-StephaneDucasse.173.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.107.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.281.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.15.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.67.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.861.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.886.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-LaurentLaffont.12.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.422.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40124.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.469.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 18:46'!
script14

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.816.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.506.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-StephaneDucasse.819.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.21.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.435.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.523.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/11/2011 17:53'!
script140

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.174.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.283.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.15.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.67.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.33.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.861.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.886.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.424.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40125.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.469.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 4/11/2011 22:39'!
script141

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.174.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.283.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.15.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.67.mcz
Files-MarcusDenker.ducasse.200.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.34.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.55.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.861.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.887.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-StephaneDucasse.425.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-StephaneDucasse.40126.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.469.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.575.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/12/2011 09:05'!
script142

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Exceptions-MarcusDenker.67.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.34.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.56.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.862.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.888.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.426.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-StephaneDucasse.40126.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.470.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.576.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/12/2011 10:07'!
script143

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.55.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.56.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.12.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.862.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.888.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.427.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.471.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.576.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/12/2011 22:48'!
script144

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.862.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-MarcusDenker.30.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.91.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.889.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-MarcusDenker.22.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.50.mcz
Polymorph-Widgets-MarcusDenker.428.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.74.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.223.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.471.mcz
System-Text-MarcusDenker.156.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.114.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.576.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-MarcusDenker.32.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 4/13/2011 09:18'!
script145

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.43.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.862.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.890.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-StephaneDucasse.51.mcz
Polymorph-Widgets-StephaneDucasse.429.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.75.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.472.mcz
System-Text-StephaneDucasse.157.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.281.mcz
ToolBuilder-Kernel-StephaneDucasse.62.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.577.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/13/2011 11:24'!
script146

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.43.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.862.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.890.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-StephaneDucasse.51.mcz
Polymorph-Widgets-StephaneDucasse.429.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.75.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-MarcusDenker.62.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.473.mcz
System-Text-StephaneDucasse.157.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-StephaneDucasse.62.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.577.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/13/2011 15:13'!
script147

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.43.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.862.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.890.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-StephaneDucasse.51.mcz
Polymorph-Widgets-StephaneDucasse.429.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.75.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-MarcusDenker.62.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.474.mcz
System-Text-StephaneDucasse.157.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-StephaneDucasse.62.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.577.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/14/2011 11:35'!
script148

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-MarcusDenker.16.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-StephaneDucasse.43.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.863.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.891.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-StephaneDucasse.51.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.75.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-MarcusDenker.62.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.474.mcz
System-Text-StephaneDucasse.157.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.578.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/14/2011 14:11'!
script149

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.17.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-MarcusDenker.45.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.863.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.892.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-StephaneDucasse.51.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40127.mcz
SUnitGUI-StephaneDucasse.75.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.5.mcz
System-Download-MarcusDenker.62.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.476.mcz
System-Text-StephaneDucasse.157.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.578.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/22/2011 09:56'!
script15

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.817.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.375.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-StephaneDucasse.21.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-StephaneDucasse.435.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.523.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/14/2011 15:49'!
script150

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.80.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.201.mcz
Finder-MarcusDenker.45.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.863.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.893.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.62.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.477.mcz
System-Text-StephaneDucasse.157.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.578.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/15/2011 10:42'!
script151

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.81.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.45.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.864.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.92.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.894.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.478.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.578.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/15/2011 13:59'!
script152

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.81.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.46.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.864.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.93.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.894.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.48.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.478.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.579.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 4/15/2011 15:01'!
script153

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.81.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.46.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.864.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.93.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.894.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.48.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.478.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.579.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 4/15/2011 15:16'!
script154

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.81.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.46.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.865.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.93.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.894.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.48.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-StephaneDucasse.72.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.99.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-MarcusDenker.126.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.224.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.478.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-MarcusDenker.45.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.579.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 4/15/2011 15:40'!
script155

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.81.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.865.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-IgorStasenko.895.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.48.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-IgorStasenko.100.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-IgorStasenko.225.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-IgorStasenko.479.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-IgorStasenko.580.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-StephaneDucasse.33.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/15/2011 16:21'!
script156

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.131.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.865.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-IgorStasenko.895.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.48.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-MarcusDenker.11.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-MarcusDenker.430.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-MarcusDenker.40128.mcz
SUnitGUI-MarcusDenker.76.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-IgorStasenko.100.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-IgorStasenko.225.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-IgorStasenko.479.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-IgorStasenko.580.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 4/15/2011 20:25'!
script157

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.131.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.865.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-IgorStasenko.895.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.48.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-IgorStasenko.100.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-IgorStasenko.225.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-IgorStasenko.479.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.283.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-IgorStasenko.580.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/16/2011 19:14'!
script158

	^ 'Announcements-Core-MarcusDenker.20.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.131.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.284.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.18.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.865.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-IgorStasenko.895.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.101.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-IgorStasenko.225.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.480.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.284.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.582.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/18/2011 10:13'!
script159

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.131.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.88.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.19.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.865.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.896.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-IgorStasenko.225.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.481.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.284.mcz
ToolBuilder-Kernel-MarcusDenker.63.mcz
ToolBuilder-Morphic-StephaneDucasse.115.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.582.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/22/2011 19:52'!
script16

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.817.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.377.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.436.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.523.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.24.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/18/2011 12:54'!
script160

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.131.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.89.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.19.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.868.mcz
KernelTests-MarcusDenker.321.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-MarcusDenker.6.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.226.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.481.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.285.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.582.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/18/2011 17:09'!
script161

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.131.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.89.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.19.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.868.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.14.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-MarcusDenker.6.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.226.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.481.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.583.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/19/2011 09:50'!
script162

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.89.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.109.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.20.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.870.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-MarcusDenker.7.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.481.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.583.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/19/2011 23:40'!
script163

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.89.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.175.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.20.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.870.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.515.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.11.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Launcher-MarcusDenker.7.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.481.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.583.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/20/2011 10:51'!
script164

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.89.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.507.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.20.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.870.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.483.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.583.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/20/2011 20:26'!
script165

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.20.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.872.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.483.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.583.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/20/2011 20:41'!
script166

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.20.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.543.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.872.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.484.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.583.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/21/2011 10:22'!
script167

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.20.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.544.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.872.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-IgorStasenko.94.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-MarcusDenker.57.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.30.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.485.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.584.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/21/2011 18:28'!
script168

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.21.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-IgorStasenko.47.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.544.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.872.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.95.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-MarcusDenker.57.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.30.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.486.mcz
System-Text-MarcusDenker.158.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.584.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/21/2011 19:18'!
script169

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.21.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.50.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.544.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.872.mcz
KernelTests-MarcusDenker.322.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.95.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.897.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-MarcusDenker.57.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.24.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.30.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.486.mcz
System-Text-MarcusDenker.159.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.286.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.584.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/24/2011 13:21'!
script17

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.818.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.378.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.25.mcz
SimpleMorphic-StephaneDucasse.10.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.436.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.106.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.24.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/23/2011 10:13'!
script170

	^ 'Announcements-Core-MarcusDenker.21.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.133.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.21.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.51.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.544.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.872.mcz
KernelTests-MarcusDenker.323.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.95.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.898.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-MarcusDenker.57.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.25.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.30.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.487.mcz
System-Text-MarcusDenker.159.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.287.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.585.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/25/2011 10:18'!
script171

	^ 'Announcements-Core-MarcusDenker.23.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.135.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.87.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-IgorStasenko.79.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.21.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.51.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.544.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.874.mcz
KernelTests-MarcusDenker.323.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.95.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.898.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-MarcusDenker.59.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.25.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.30.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.488.mcz
System-Text-MarcusDenker.159.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.287.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.585.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 4/26/2011 22:53'!
script172

	^ 'Announcements-Core-MarcusDenker.23.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.78.mcz
Collections-Abstract-MarcusDenker.135.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Atomic-IgorStasenko.3.mcz
Collections-Native-MarcusDenker.3.mcz
Collections-Sequenceable-MarcusDenker.90.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.90.mcz
Collections-Strings-MarcusDenker.176.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-MarcusDenker.58.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-MarcusDenker.111.mcz
Collections-Weak-MarcusDenker.56.mcz
CollectionsTests-MarcusDenker.508.mcz
Compiler-MarcusDenker.285.mcz
CompilerTests-MarcusDenker.83.mcz
Compression-MarcusDenker.81.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-MarcusDenker.6.mcz
Deprecated13-MarcusDenker.21.mcz
DialogItemsChooser-MarcusDenker.14.mcz
EmergencyEvaluator-MarcusDenker.7.mcz
Files-MarcusDenker.ducasse.202.mcz
Finder-MarcusDenker.52.mcz
FixUnderscores-IgorStasenko.21.mcz
FreeType-MarcusDenker.544.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-MarcusDenker.129.mcz
Graphics-Display Objects-MarcusDenker.57.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-MarcusDenker.21.mcz
Graphics-Fonts-MarcusDenker.24.mcz
Graphics-Primitives-StephaneDucasse.56.mcz
Graphics-Resources-MarcusDenker.10.mcz
Graphics-Support-MarcusDenker.12.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-MarcusDenker.13.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.80.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.875.mcz
KernelTests-MarcusDenker.323.mcz
MenuRegistration-StephaneDucasse.31.mcz
Monticello-MarcusDenker.516.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-MarcusDenker.95.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.898.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-MarcusDenker.13.mcz
Multilingual-Encodings-MarcusDenker.12.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-MarcusDenker.11.mcz
Multilingual-Scanning-StephaneDucasse.23.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-StephaneDucasse.19.mcz
Network-Kernel-MarcusDenker.61.mcz
Network-MIME-MarcusDenker.37.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.64.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.50.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.49.mcz
NetworkTests-MarcusDenker.49.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-LaurentLaffont.12.mcz
Polymorph-Geometry-LaurentLaffont.8.mcz
Polymorph-TaskbarIcons-StephaneDucasse.9.mcz
Polymorph-ToolBuilder-StephaneDucasse.39.mcz
Polymorph-Tools-Diff-MarcusDenker.52.mcz
Polymorph-Widgets-LaurentLaffont.431.mcz
RecentSubmissions-IgorStasenko.73.mcz
Regex-Core-MarcusDenker.4.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
SUnit-LaurentLaffont.40129.mcz
SUnitGUI-LaurentLaffont.77.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.7.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-MarcusDenker.8.mcz
Settings-Polymorph-MarcusDenker.27.mcz
Settings-System-MarcusDenker.17.mcz
Settings-Tools-StephaneDucasse.32.mcz
SimpleMorphic-MarcusDenker.25.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-MarcusDenker.30.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-MarcusDenker.102.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.6.mcz
System-Download-MarcusDenker.63.mcz
System-FilePackage-IgorStasenko.50.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-Hashing-MarcusDenker.16.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.11.mcz
System-Localization-MarcusDenker.58.mcz
System-Object Events-MarcusDenker.9.mcz
System-Object Storage-IgorStasenko.127.mcz
System-Platforms-MarcusDenker.15.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-MarcusDenker.227.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.488.mcz
System-Text-MarcusDenker.160.mcz
System-Tools-IgorStasenko.46.mcz
Tests-MarcusDenker.287.mcz
ToolBuilder-Kernel-MarcusDenker.64.mcz
ToolBuilder-Morphic-MarcusDenker.116.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.585.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-MarcusDenker.24.mcz
UI-Basic-MarcusDenker.4.mcz
UIManager-MarcusDenker.35.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/25/2011 13:15'!
script18

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.4.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.819.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.822.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.378.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.26.mcz
SimpleMorphic-MarcusDenker.11.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.437.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.107.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.25.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/26/2011 09:28'!
script19

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.820.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.380.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.26.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/19/2011 15:46'!
script2

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.24.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-StephaneDucasse.72.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.810.mcz
KernelTests-MarcusDenker.303.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.816.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.369.mcz
RecentSubmissions-StephaneDucasse.60.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.15.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.261.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/26/2011 11:32'!
script20

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.821.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.381.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.267.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.26.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/26/2011 14:31'!
script21

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-MarcusDenker.821.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.381.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.27.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 14:49'!
script22

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.191.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.822.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-MarcusDenker.23.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-MarcusDenker.27.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 15:18'!
script23

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.124.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-StephaneDucasse.83.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.191.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.45.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.49.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.822.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 16:22'!
script24

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-MarcusDenker.69.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.824.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.524.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 17:18'!
script25

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.824.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.525.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/28/2011 18:03'!
script26

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.824.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.525.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/29/2011 12:02'!
script27

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.526.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/29/2011 12:11'!
script28

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.824.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-MarcusDenker.438.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.527.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/29/2011 13:32'!
script29

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/20/2011 10:38'!
script3

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-StephaneDucasse.810.mcz
KernelTests-MarcusDenker.303.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.816.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.371.mcz
RecentSubmissions-StephaneDucasse.60.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.15.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.261.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/30/2011 12:41'!
script30

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-MarcusDenker.22.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 13:43'!
script31

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.825.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.24.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-MarcusDenker.6.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 14:02'!
script32

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.826.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.12.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 16:57'!
script33

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.827.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.128.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/31/2011 22:11'!
script34

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.126.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.827.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.440.mcz
System-Text-StephaneDucasse.131.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.269.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/1/2011 07:44'!
script35

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.827.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.442.mcz
System-Text-StephaneDucasse.131.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.271.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 2/2/2011 15:51'!
script36

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.47.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.829.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.382.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.442.mcz
System-Text-StephaneDucasse.131.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.271.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/4/2011 21:44'!
script37

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-MarcusDenker.214.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.442.mcz
System-Text-StephaneDucasse.131.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.271.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/6/2011 10:01'!
script38

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.442.mcz
System-Text-StephaneDucasse.132.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.271.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 2/6/2011 12:52'!
script39

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.442.mcz
System-Text-StephaneDucasse.132.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.271.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/20/2011 12:58'!
script4

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
DeleteMe-StephaneDucasse.1.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-StephaneDucasse.816.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-StephaneDucasse.60.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/6/2011 21:22'!
script40

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.132.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.528.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/6/2011 22:34'!
script41

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.132.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.529.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/7/2011 13:09'!
script42

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.133.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.529.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/7/2011 17:52'!
script43

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.133.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.530.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/7/2011 18:22'!
script44

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.61.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.133.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.530.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/10/2011 12:11'!
script45

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.61.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.384.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.133.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.530.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/10/2011 15:05'!
script46

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.385.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.16.mcz
System-Changes-StephaneDucasse.94.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.532.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/10/2011 16:07'!
script47

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.70.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.385.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.532.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/10/2011 17:40'!
script48

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.385.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.532.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 2/10/2011 18:21'!
script49

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.81.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.831.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.385.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.532.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/20/2011 22:12'!
script5

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.817.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/10/2011 20:43'!
script50

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.832.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.385.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.19.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.216.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.533.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/12/2011 14:29'!
script51

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.832.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.386.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.20.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.217.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.444.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.534.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/12/2011 16:49'!
script52

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.832.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.389.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.20.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.217.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.446.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.534.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 2/13/2011 16:56'!
script53

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.832.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.389.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.20.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.217.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.446.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-LaurentLaffont.535.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/14/2011 13:22'!
script54

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.832.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.389.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.20.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.217.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.536.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/16/2011 10:20'!
script55

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.833.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.389.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.20.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.217.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.537.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/16/2011 11:17'!
script56

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.19.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.833.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.391.mcz
RecentSubmissions-MarcusDenker.64.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.20.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-MarcusDenker.27.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.217.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.135.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.537.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/22/2011 15:41'!
script57

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.24.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.827.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.837.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.392.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-StephaneDucasse.31.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.142.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.539.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/22/2011 17:27'!
script58

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.24.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.837.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.392.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-StephaneDucasse.31.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.142.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.540.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/22/2011 17:48'!
script59

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.84.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.24.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.839.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.394.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.15.mcz
Settings-Tools-StephaneDucasse.31.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.143.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.541.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/21/2011 10:41'!
script6

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-StephaneDucasse.125.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 2/22/2011 18:48'!
script60

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.24.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-StephaneDucasse.132.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.507.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.840.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-StephaneDucasse.394.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.143.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.542.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-StephaneDucasse.28.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 2/23/2011 20:30'!
script61

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.24.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-LaurentLaffont.841.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.394.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.143.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.542.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 2/24/2011 20:25'!
script62

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.25.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.843.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-StephaneDucasse.44.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.394.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-MarcusDenker.145.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.544.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 2/24/2011 21:16'!
script63

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.25.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-LaurentLaffont.75.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.844.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.394.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-MarcusDenker.145.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.544.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'AlainPlantec 2/25/2011 15:26'!
script64

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.25.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-AlainPlantec.78.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.844.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-AlainPlantec.395.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-StephaneDucasse.23.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-StephaneDucasse.221.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-MarcusDenker.145.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-AlainPlantec.546.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-StephaneDucasse.2.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'AlainPlantec 2/25/2011 17:21'!
script65

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.127.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.25.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-AlainPlantec.78.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.829.mcz
KernelTests-StephaneDucasse.306.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-AlainPlantec.845.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-AlainPlantec.395.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-MarcusDenker.145.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-AlainPlantec.547.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/1/2011 14:27'!
script66

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.28.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-AlainPlantec.78.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.830.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-AlainPlantec.845.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-AlainPlantec.395.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.148.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-AlainPlantec.547.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/1/2011 15:14'!
script67

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.72.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.28.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-AlainPlantec.78.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.830.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-AlainPlantec.845.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-AlainPlantec.395.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.13.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.148.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-AlainPlantec.547.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/1/2011 21:35'!
script68

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.28.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.51.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-AlainPlantec.78.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.831.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.846.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.396.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.14.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.548.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/4/2011 14:30'!
script69

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-AlainPlantec.78.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.831.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.846.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.396.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.14.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.550.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/21/2011 11:09'!
script7

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.811.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.502.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-StephaneDucasse.1.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.429.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.262.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.513.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/4/2011 15:30'!
script70

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.831.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.846.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.396.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.14.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.550.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 3/4/2011 22:49'!
script71

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-MarcusDenker.63.mcz
Kernel-StephaneDucasse.831.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.87.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-LaurentLaffont.847.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-LaurentLaffont.397.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-LaurentLaffont.15.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-MarcusDenker.108.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-LaurentLaffont.551.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-LaurentLaffont.29.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/6/2011 22:11'!
script72

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.49.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.831.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.848.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.398.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-LaurentLaffont.15.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.109.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.552.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/7/2011 16:35'!
script73

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.831.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.850.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.398.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.109.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.554.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/7/2011 17:31'!
script74

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.832.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.850.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.398.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.109.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.554.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/7/2011 22:43'!
script75

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.832.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.851.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.399.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.109.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.554.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/8/2011 18:50'!
script76

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.832.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.46.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.399.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.109.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.554.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/10/2011 16:00'!
script77

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.832.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.401.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.554.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/12/2011 11:46'!
script78

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-MarcusDenker.33.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.832.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.401.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.554.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/12/2011 13:35'!
script79

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.166.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-StephaneDucasse.1.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.35.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.832.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-StephaneDucasse.401.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.555.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-StephaneDucasse.30.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 1/21/2011 12:56'!
script8

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-MarcusDenker.79.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.494.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.813.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.518.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'SeedFxing 3/12/2011 14:30'!
script80

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-SeedFxing.167.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-SeedFxing.262.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.193.mcz
Finder-StephaneDucasse.35.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-SeedFxing.833.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-Support-StephaneDucasse.447.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.555.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/12/2011 15:11'!
script81

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.85.mcz
Collections-Strings-StephaneDucasse.168.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.263.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.36.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-SeedFxing.833.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.449.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.273.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.556.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/12/2011 16:06'!
script82

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.264.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.36.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.834.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.274.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.556.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/13/2011 12:03'!
script83

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.500.mcz
Compiler-StephaneDucasse.268.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.837.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.852.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.274.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/13/2011 12:19'!
script84

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.500.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.838.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.274.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/13/2011 12:48'!
script85

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.838.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.95.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/14/2011 12:40'!
script86

	^ 'Announcements-Core-StephaneDucasse.15.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.838.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/14/2011 13:01'!
script87

	^ 'Announcements-Core-StephaneDucasse.15.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.839.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/14/2011 13:17'!
script88

	^ 'Announcements-Core-StephaneDucasse.18.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.6.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-StephaneDucasse.839.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'IgorStasenko 3/14/2011 13:28'!
script89

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.840.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.450.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 1/21/2011 14:50'!
script9

	^ 'Announcements-Core-StephaneDucasse.11.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-StephaneDucasse.2.mcz
Announcements-View-StephaneDucasse.6.mcz
Balloon-StephaneDucasse.53.mcz
Collections-Abstract-MarcusDenker.123.mcz
Collections-Arrayed-StephaneDucasse.61.mcz
Collections-Sequenceable-MarcusDenker.82.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.80.mcz
Collections-Strings-StephaneDucasse.165.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.5.mcz
Collections-Unordered-MarcusDenker.105.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.495.mcz
Compiler-StephaneDucasse.261.mcz
CompilerTests-StephaneDucasse.68.mcz
Compression-MarcusDenker.75.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated12-StephaneDucasse.3.mcz
DialogItemsChooser-MarcusDenker.9.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.65.mcz
Files-StephaneDucasse.ducasse.190.mcz
Finder-StephaneDucasse.18.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-MarcusDenker.27.mcz
Gofer-Core-MarcusDenker.129.mcz
Gofer-Tests-StephaneDucasse.125.mcz
Graphics-Display Objects-FixesFinderAndOthers.44.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.17.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-StephaneDucasse.48.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-StephaneDucasse.10.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.74.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.60.mcz
Kernel-MarcusDenker.813.mcz
KernelTests-MarcusDenker.304.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-MarcusDenker.504.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.85.mcz
MonticelloMocks-MarcusDenker.3.mcz
Morphic-MarcusDenker.818.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.8.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-MarcusDenker.9.mcz
Multilingual-Scanning-StephaneDucasse.16.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-MarcusDenker.54.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.60.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-MarcusDenker.45.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-MarcusDenker.47.mcz
NetworkTests-MarcusDenker.43.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.5.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-StephaneDucasse.42.mcz
Polymorph-Widgets-MarcusDenker.372.mcz
RecentSubmissions-MarcusDenker.63.mcz
Regex-Core-StephaneDucasse.2.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.169.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-StephaneDucasse.70.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-MarcusDenker.17.mcz
Settings-System-MarcusDenker.13.mcz
Settings-Tools-StephaneDucasse.24.mcz
SimpleMorphic-StephaneDucasse.9.mcz
System-Applications-StephaneDucasse.20.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.15.mcz
System-Changes-StephaneDucasse.92.mcz
System-Clipboard-StephaneDucasse.19.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-StephaneDucasse.57.mcz
System-FilePackage-StephaneDucasse.48.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.5.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-StephaneDucasse.55.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.118.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.15.mcz
System-Settings-StephaneDucasse.211.mcz
System-Sound-StephaneDucasse.3.mcz
System-Support-MarcusDenker.433.mcz
System-Text-MarcusDenker.127.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.265.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.105.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.518.mcz
ToolsTest-StephaneDucasse.denker.15.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UIManager-StephaneDucasse.23.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/14/2011 14:49'!
script90

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-StephaneDucasse.ducasse.195.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-IgorStasenko.840.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.453.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/15/2011 14:19'!
script91

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.196.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.841.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.854.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-StephaneDucasse.9.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-AlainPlantec.24.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.453.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-StephaneDucasse.558.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'LaurentLaffont 3/15/2011 20:56'!
script92

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-LaurentLaffont.842.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-LaurentLaffont.855.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.453.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-LaurentLaffont.559.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.386.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/18/2011 09:29'!
script93

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-StephaneDucasse.54.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-StephaneDucasse.38.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-LaurentLaffont.842.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.856.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.453.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-StephaneDucasse.276.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-LaurentLaffont.559.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-StephaneDucasse.387.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/18/2011 12:46'!
script94

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-StephaneDucasse.85.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.52.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-MarcusDenker.41.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-LaurentLaffont.842.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.858.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.455.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-LaurentLaffont.559.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.389.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/18/2011 13:26'!
script95

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-MarcusDenker.41.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-LaurentLaffont.842.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.858.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-StephaneDucasse.16.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.455.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-LaurentLaffont.559.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/18/2011 21:27'!
script96

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-MarcusDenker.41.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-LaurentLaffont.842.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-LaurentLaffont.508.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-MarcusDenker.858.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.69.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.17.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.97.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-MarcusDenker.120.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.455.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.560.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'StephaneDucasse 3/20/2011 11:33'!
script97

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-LaurentLaffont.842.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.859.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.17.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-StephaneDucasse.456.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.560.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/21/2011 11:22'!
script98

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-LaurentLaffont.ducasse.197.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.843.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.859.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.34.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.17.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.560.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'pharo - scripts' stamp: 'MarcusDenker 3/21/2011 14:39'!
script99

	^ 'Announcements-Core-IgorStasenko.19.mcz
Announcements-Help-StephaneDucasse.2.mcz
Announcements-Tests-Core-IgorStasenko.7.mcz
Announcements-View-IgorStasenko.7.mcz
Balloon-StephaneDucasse.75.mcz
Collections-Abstract-StephaneDucasse.129.mcz
Collections-Arrayed-StephaneDucasse.63.mcz
Collections-Native-StephaneDucasse.2.mcz
Collections-Sequenceable-MarcusDenker.86.mcz
Collections-Stack-MarcusDenker.7.mcz
Collections-Streams-StephaneDucasse.86.mcz
Collections-Strings-StephaneDucasse.169.mcz
Collections-Support-MarcusDenker.38.mcz
Collections-Tests-Strings-StephaneDucasse.2.mcz
Collections-Tests-Text-StephaneDucasse.2.mcz
Collections-Text-MarcusDenker.57.mcz
Collections-Traits-StephaneDucasse.6.mcz
Collections-Unordered-StephaneDucasse.106.mcz
Collections-Weak-MarcusDenker.54.mcz
CollectionsTests-StephaneDucasse.501.mcz
Compiler-StephaneDucasse.269.mcz
CompilerTests-StephaneDucasse.73.mcz
Compression-StephaneDucasse.78.mcz
CompressionTests-MarcusDenker.2.mcz
Deprecated11-SeedFxing.2.mcz
Deprecated12-MarcusDenker.5.mcz
Deprecated13-StephaneDucasse.1.mcz
DialogItemsChooser-StephaneDucasse.12.mcz
EmergencyEvaluator-StephaneDucasse.6.mcz
Exceptions-MarcusDenker.66.mcz
Files-MarcusDenker.ducasse.198.mcz
Finder-StephaneDucasse.42.mcz
FixUnderscores-StephaneDucasse.20.mcz
FreeType-StephaneDucasse.542.mcz
FreeTypeSubPixelAntiAliasing-StephaneDucasse.23.mcz
FreeTypeTests-StephaneDucasse.3.mcz
Glamour-Morphic-Theme-StephaneDucasse.32.mcz
Gofer-Core-LaurentLaffont.133.mcz
Gofer-Tests-StephaneDucasse.128.mcz
Graphics-Display Objects-StephaneDucasse.51.mcz
Graphics-External-MarcusDenker.7.mcz
Graphics-Files-StephaneDucasse.19.mcz
Graphics-Fonts-StephaneDucasse.21.mcz
Graphics-Primitives-MarcusDenker.53.mcz
Graphics-Resources-MarcusDenker.9.mcz
Graphics-Support-StephaneDucasse.11.mcz
Graphics-Tests-StephaneDucasse.10.mcz
Graphics-Text-LaurentLaffont.11.mcz
Graphics-Transformations-StephaneDucasse.4.mcz
HelpSystem-Core-MarcusDenker.79.mcz
HelpSystem-Tests-StephaneDucasse.19.mcz
HostMenus-StephaneDucasse.65.mcz
Kernel-MarcusDenker.843.mcz
KernelTests-StephaneDucasse.307.mcz
MenuRegistration-StephaneDucasse.29.mcz
MimeConverter-MarcusDenker.9.mcz
Monticello-StephaneDucasse.509.mcz
MonticelloConfigurations-StephaneDucasse.60.mcz
MonticelloGUI-StephaneDucasse.88.mcz
MonticelloMocks-MarcusDenker.5.mcz
Morphic-StephaneDucasse.859.mcz
MorphicTests-StephaneDucasse.35.mcz
Multilingual-Display-StephaneDucasse.10.mcz
Multilingual-Encodings-StephaneDucasse.9.mcz
Multilingual-ImmPlugin-LaurentLaffont.10.mcz
Multilingual-Languages-StephaneDucasse.10.mcz
Multilingual-Scanning-StephaneDucasse.21.mcz
Multilingual-Tests-MarcusDenker.8.mcz
Multilingual-TextConversion-MarcusDenker.18.mcz
Network-Kernel-StephaneDucasse.56.mcz
Network-MIME-MarcusDenker.35.mcz
Network-MailSending-MarcusDenker.11.mcz
Network-Protocols-StephaneDucasse.62.mcz
Network-RFC822-StephaneDucasse.4.mcz
Network-RemoteDirectory-StephaneDucasse.48.mcz
Network-URI-MarcusDenker.28.mcz
Network-UUID-StephaneDucasse.17.mcz
Network-Url-StephaneDucasse.48.mcz
NetworkTests-MarcusDenker.45.mcz
PackageInfo-StephaneDucasse.69.mcz
Polymorph-EventEnhancements-StephaneDucasse.10.mcz
Polymorph-Geometry-stephane_ducasse.5.mcz
Polymorph-TaskbarIcons-StephaneDucasse.8.mcz
Polymorph-ToolBuilder-StephaneDucasse.38.mcz
Polymorph-Tools-Diff-LaurentLaffont.43.mcz
Polymorph-Widgets-SeedFxing.402.mcz
RecentSubmissions-StephaneDucasse.71.mcz
Regex-Core-SeedFxing.3.mcz
Regex-Help-StephaneDucasse.2.mcz
Regex-Tests-Core-StephaneDucasse.3.mcz
ST80-StephaneDucasse.170.mcz
SUnit-MarcusDenker.40122.mcz
SUnitGUI-MarcusDenker.73.mcz
Settings-Compiler-StephaneDucasse.3.mcz
Settings-Display-StephaneDucasse.2.mcz
Settings-FreeType-StephaneDucasse.2.mcz
Settings-Graphics-StephaneDucasse.6.mcz
Settings-Kernel-StephaneDucasse.2.mcz
Settings-Monticello-StephaneDucasse.4.mcz
Settings-Network-StephaneDucasse.7.mcz
Settings-Polymorph-LaurentLaffont.25.mcz
Settings-System-StephaneDucasse.16.mcz
Settings-Tools-StephaneDucasse.32.mcz
Shout-MarcusDenker.1.mcz
SimpleMorphic-MarcusDenker.18.mcz
StratifiedProxy-StephaneDucasse.1.mcz
System-Applications-StephaneDucasse.29.mcz
System-BreakPoints-StephaneDucasse.1.mcz
System-Change Notification-StephaneDucasse.17.mcz
System-Changes-StephaneDucasse.98.mcz
System-Clipboard-StephaneDucasse.23.mcz
System-Debugging-MarcusDenker.4.mcz
System-Digital Signatures-StephaneDucasse.15.mcz
System-Download-LaurentLaffont.58.mcz
System-FilePackage-StephaneDucasse.49.mcz
System-FileRegistry-StephaneDucasse.13.mcz
System-Finalization-MarcusDenker.15.mcz
System-GUISupport-StephaneDucasse.7.mcz
System-Hashing-StephaneDucasse.11.mcz
System-History-MarcusDenker.4.mcz
System-Installers-MarcusDenker.10.mcz
System-Launcher-StephaneDucasse.5.mcz
System-Localization-LaurentLaffont.56.mcz
System-Object Events-StephaneDucasse.8.mcz
System-Object Storage-StephaneDucasse.122.mcz
System-Platforms-MarcusDenker.15.mcz
System-Pools-sd.2.mcz
System-Serial Port-StephaneDucasse.18.mcz
System-Settings-AlainPlantec.222.mcz
System-Sound-StephaneDucasse.10.mcz
System-SourceAndChangeFile-StephaneDucasse.1.mcz
System-Support-MarcusDenker.457.mcz
System-Text-StephaneDucasse.149.mcz
System-Tools-StephaneDucasse.43.mcz
Tests-MarcusDenker.278.mcz
ToolBuilder-Kernel-StephaneDucasse.61.mcz
ToolBuilder-Morphic-StephaneDucasse.111.mcz
ToolBuilder-SUnit-adrian_lienhard.24.mcz
Tools-MarcusDenker.560.mcz
ToolsTest-MarcusDenker.denker.16.mcz
Traits-MarcusDenker.390.mcz
TrueType-StephaneDucasse.23.mcz
UI-Basic-AlainPlantec.3.mcz
UIManager-SeedFxing.31.mcz
VB-SeedFxing.1.mcz'
findTokens: String lf , String cr! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 11/13/2010 22:30'!
setToRepositoriesPassword: aPassword to: aUser
	"self new setToRepositoriesPassword: 'sd' to: 'zork'"
	
	MCRepositoryGroup instVarNamed: 'default' put: nil. 
	self removeAllHTTPRepositories: {self repository locationWithTrailingSlash . self inboxRepository locationWithTrailingSlash}. 
	self repository password: aPassword.
	self repository user: aUser.
	self inboxRepository password: aPassword.
	self inboxRepository user: aUser.
	self addHomeRepositoryToAllPackages! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'adrian lienhard 11/7/2008 22:07'!
setUpdateAndScriptVersionNumbers
	CurrentUpdateVersionNumber := self getLatestUpdateNumber + 1.
	CurrentScriptVersionNumber := self getLatestScriptNumber + 1.! !

!ScriptLoader methodsFor: 'utils' stamp: 'StephaneDucasse 11/8/2010 22:09'!
shortImageName
	"should be removed when the version  will be integrated in SmalltalkImage"
	
	^ FileDirectory baseNameFor: (FileDirectory default localNameFor: Smalltalk imageName).! !

!ScriptLoader methodsFor: 'accessing' stamp: 'StephaneDucasse 11/13/2010 22:21'!
theScriptLoaderPackageName
	^'ScriptLoader',  CurrentMajorVersionNumber asString copyWithout: $. ! !

!ScriptLoader methodsFor: 'mc public utils' stamp: 'stephane.ducasse 1/13/2009 10:58'!
unloadPackage: aString
	"self new unloadPackage: 'Sixx'"
	| toRemove | 
	toRemove := (MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ]) detect: [:each | each package name = aString].
	toRemove unload.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'stephane.ducasse 2/6/2009 17:36'!
unloadPackageNamed: aString
	"self new workingCopyFromPackageName: 'CollectionExtensions' "
	
	^ (self workingCopyFromPackageName: aString) unload
	! !

!ScriptLoader methodsFor: 'mc related utils' stamp: 'sd 7/15/2006 20:39'!
unloadPackages
	"ScriptLoader new unloadPackages"
	
	| copies namesOfpackagesToUnload |
	namesOfpackagesToUnload := self packagesToUnload. 
	copies := MCWorkingCopy allManagers asSortedCollection:
		[ :a :b | a package name <= b package name ].
	(copies select: [:each | namesOfpackagesToUnload anySatisfy: [:ea | ea match: each package name ]])
		do: [:z | z unload].! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/19/2011 15:42'!
update13000! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/19/2011 15:41'!
update13001! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/19/2011 15:46'!
update13002
	"self new update13002"
	self withUpdateLog: 'Issue 3422:	Use UIManager instead of Workspace
Issue 3509:	Multi-part MIME support for MailMessage
'.
	self loadTogether: self script2 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/20/2011 10:38'!
update13003
	"self new update13003"
	self withUpdateLog: 'Issue 3555:	HelpBrowser shoudl display Help as title, already integrated but reverted
Issue 3553:	GeneralScrollPane should support both spaceFill and shrinkWrap
Issue 3543:	Merge latest Glamour theme
'.
	self loadTogether: self script3 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/20/2011 12:58'!
update13004
	"self new update13004"
	self withUpdateLog: 'Issue 3558:	Delete empty package ScriptLoader12.
Issue 3552:	Delete Package DeleteMe
Issue 3550:	MenuItemMorph>>mouseDown: has unnecessary check
Issue 3468:	Perform and context frame size primitive tests
Issue 3441:	Tests for Polymorph
Issue 3378:	Process remove depende to UIManager
Issue 3557:	[Feature]: Setting for easy select i.e. selecting in the world by dragging'.
	self loadTogether: self script4 merge: false.
	ScriptLoader new deletePackage: 'DeleteMe'.
ScriptLoader new deletePackage: 'ScriptLoader12'.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/20/2011 22:12'!
update13005
	"self new update13005"
	self withUpdateLog: 'Issue 3560:	Clean of RML
Issue 3559:	Remodularization of BalloonMorph'.
	self loadTogether: self script5 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/21/2011 10:41'!
update13006
	"self new update13006"
	self withUpdateLog: 'Issue 3556:	PluggableTextMorph(Object)>>doesNotUnderstand: #stylerStyled:'.
	self loadTogether: self script6 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/21/2011 11:09'!
update13007
	"self new update13007"
	self withUpdateLog: 'Issue 3520:	Workspaces do not recognize previously evaluated temps'.
	self loadTogether: self script7 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/21/2011 12:56'!
update13008
	"self new update13008"
	self withUpdateLog: 'Issue 3564:	Comparison of source references (for sorting)
Issue 3179:	Failing Tests for Monticello'.
	self loadTogether: self script8 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 14:50'!
update13009
	"self new update13009"
	self withUpdateLog: '-  Issue 3527:	Generator. Thanks Ralph Boland'.
	self loadTogether: self script9 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 15:20'!
update13010
	"self new update13010"
	self withUpdateLog: '- Issue 3361:	CompiledMethod copy. Thanks Gabriel Barbuto.'.
	self loadTogether: self script10 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 17:01'!
update13011
	"self new update13011"
	self withUpdateLog: '- Issue 2757:	Refactor StringHolder. Thanks Guillermo Polito.'.
	self loadTogether: self script11 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 17:36'!
update13012
	"self new update13012"
	self withUpdateLog: '- Issue 3440:	Cycle in Monticello removed.
- Little workspace fixes'.
	self loadTogether: self script12 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 18:31'!
update13013
	"self new update13013"
	self withUpdateLog: '- Categorization of deprecated methods.'.
	self loadTogether: self script13 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/21/2011 18:47'!
update13014
	"self new update13014"
	self withUpdateLog: '- Issue 3569:	Error logging cleanup. Thanks Igor Stasenko.'.
	self loadTogether: self script14 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/22/2011 09:56'!
update13015
	"self new update13015"
	self withUpdateLog: 'Issue 3500:	Create deprecated13
Issue 3563:	PCCByCompilationTest tests sometimes fail randomly
Issue 3179:	Failing Tests for Monticello
Issue 3570:	EdgeGripMorph DNU when resizing'.
	self loadTogether: self script15 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/22/2011 19:52'!
update13016
	"self new update13016"
	self withUpdateLog: 'Issue 3566:	Changes needed to update Sound for 1.2
Issue 3380:	UnhandleError remove dependence to UIManager'.
	self loadTogether: self script16 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/24/2011 13:21'!
update13017
	"self new update13017"
	self withUpdateLog: 'Issue 3580:	Some trivial code-critique cleanups
Issue 3582:	RecentMessageList should be reseted in #cleanUpForRelease'.
	self loadTogether: self script17 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/25/2011 13:15'!
update13018
	"self new update13018"
	self withUpdateLog: 'Issue 3593:	NoneInteractive UIManager
Issue 3051:	ContextPart>>objectSize
Issue 3335:	[Kernel Dependencies] Number>>@'.
	self loadTogether: self script18 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/26/2011 09:28'!
update13019
	"self new update13019"
	self withUpdateLog: 'Issue 3583:	Shout should only be active in code panes
Issue 3594:	Expander needs tweaking to enable resize in a TableLayout
Issue 3590:	AntiAliased fix
Issue 3596:	2nd part Headless'.
	self loadTogether: self script19 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/26/2011 11:33'!
update13020
	"self new update13020"
	self withUpdateLog: 'Issue 3596:	2nd part Headless (3rd part)
Issue 3594:	Expander needs tweaking to enable resize in a TableLayout (part 2)'.
	self loadTogether: self script20 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/26/2011 14:31'!
update13021
	"self new update13021"
	self withUpdateLog: 'Issue 3596:	2nd part Headless (again...)'.
	self loadTogether: self script21 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 14:49'!
update13022
	"self new update13022"
	self withUpdateLog: '- Issue 3597:	Fix RemoteString API. Thanks Benjamin van Ryseghem. 
- Fixed bold application in a text.
- Removed a self haltOnce: 2 in mouseEnter.
- Now we do not read back code annotation such as bold and italic. The idea is to only store code without styling annotation outside the code. It will simplify the rewrite of the system. '.
	self loadTogether: self script22 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 15:18'!
update13023
	"self new update13023"
	self withUpdateLog: '- Issue 3377:	AppRegistry remoce dependence to UIManager. Thanks Benjamin van Ryseghem.
	
- Issue 3379:	ToolSet remove dependence to UIManager. Thanks Benjamin van Ryseghem.'.
	self loadTogether: self script23 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 16:22'!
update13024
	"self new update13024"
	self withUpdateLog: '- Repackaging a lot of classes and creating UI-Basic for Model and RealEstateAgent.'.
	self loadTogether: self script24 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 17:18'!
update13025
	"self new update13025"
	self withUpdateLog: '- Issue 3614:	Fix finder with * expressions!!
- remove SelectorBrowser.
- Issue 3616:	SyntaxError listMenu: fixes
- Less ParagraphEditor references.'.
	self loadTogether: self script25 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/28/2011 18:04'!
update13026
	"self new update13026"
	self withUpdateLog: '- Fully Deprecate ParagraphEditor
- Object>>notifyWithLabel: deprecated
- Fix Pharo debug log
'.
	self loadTogether: self script26 merge: false.
	Compiler recompileAll.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/29/2011 12:02'!
update13027
	"self new update13027"
	self withUpdateLog: '- Deprecate Object>>notifyWithLabel:
- Issue 3618:	logError: aString inContext: aContext to: is used and it is deprecated	'.
	self loadTogether: self script27 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/29/2011 12:11'!
update13028
	"self new update13028"
	self withUpdateLog: '- Fully deprecate ParagraphEditor'.
	self loadTogether: self script28 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/29/2011 13:32'!
update13029
	"self new update13029"
	self withUpdateLog: '- Issue 3608:	Fix failing MessageTally tests. Thanks Marcus Denker.
- Issue 3610:	Should remove Morphic-Undo. Thanks Alain Plantec.'.
	self loadTogether: self script29 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 1/30/2011 12:41'!
update13030
	"self new update13030"
	self withUpdateLog: 'Issue 2586:	line breaks lost on Linux when copying from one pharo image to another
'.
	self loadTogether: self script30 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 13:43'!
update13031
	"self new update13031"
	self withUpdateLog: 'Issue 3626:	Clipboard broken on Unix. '.
	self loadTogether: self script31 merge: false.
	Clipboard initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 14:03'!
update13032
	"self new update13032"
	self withUpdateLog: '- Issue 3482:	InterimSoundMorph references to SketchMorph.
- Issue 3624:	LeftOver of Smalltalk and SystemDictionary. 
'.
	self loadTogether: self script32 merge: false.
	SoundService reset. 
DummySoundSystem initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 16:57'!
update13033
	"self new update13033"
	self withUpdateLog: '- Issue 3630:	Add ensureCr convenience method.
- Issue 3562:	Deferred UI messages executed slowly. Thanks Ricardo Moran!!!!'.
	self loadTogether: self script33 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 1/31/2011 22:11'!
update13034
	"self new update13034"
	self withUpdateLog: 'Issue 3472:	Text selection problem in Pharo-dev 1.2'.
	self loadTogether: self script34 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/1/2011 07:44'!
update13035
	"self new update13035"
	self withUpdateLog: '- Issue 3234:	fold: reduce: Merge. 
- Issue 3640:	better systemVersion API'.
	self loadTogether: self script35 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 2/2/2011 15:51'!
update13036
	"self new update13036"
	self withUpdateLog: 'Issue 3520:	Workspaces do not recognize previously evaluated temps
Issue 3643:	TextMorph >> enableTextChange is missing
Issue 3506:	TextMorphs #autoFit: and #wrapFlag: are confusing
'.
	self loadTogether: self script36 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/4/2011 21:45'!
update13037
	"self new update13037"
	self withUpdateLog: '-  Issue 3653:	enh: change cursor form when over active editable text morph. Thanks Alain Plantec.
- Issue 3622:	[ENH]: Clean up Url>>urlClassForScheme: Thanks Sean De Nigris'.
	self loadTogether: self script37 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/6/2011 10:01'!
update13038
	"self new update13038"
	self withUpdateLog: '- Comment of the Day Context - Day 1. Thanks Guillermo Polito, Laurent Laffont, Stephane Ducasse.
- Comment of the Day Context - Day 2. Thanks Alain Plantec, Laurent Laffont, Stephane Ducasse.
- Issue 3539:	SettingBrowser class comment is out of date. Thanks Alain Plantec'.
	self loadTogether: self script38 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 2/6/2011 12:52'!
update13039
	"self new update13039"
	self withUpdateLog: 'Issue 3658:	Dictionaries corrupt when loaded from image segment
'.
	self loadTogether: self script39 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/6/2011 21:22'!
update13040
	"self new update13040"
	self withUpdateLog: '- better comment. Thanks Alexander Lazarevic.
- Issue 3666:	Ensure that classOrTraitNamed: does not return globals. Thanks Levente Uzonyi.
- Issue 3660:	Revert incorrect Monticello branch naming support. Thanks Lukas Renggli, Julian Fitzell and Dale Henrichs'.
	self loadTogether: self script40 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/6/2011 22:39'!
update13041
	"self new update13041"
	self withUpdateLog: '- Issue 3672:	terminate suspended compiler process on window close. Thanks Alexander Lazaveric.'.
	self loadTogether: self script41 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/7/2011 13:09'!
update13042
	"self new update13042"
	self withUpdateLog: '- Issue 3682:	multiple undo/redo is broken in 1.2 because of Ocompletion. Thanks Alain Plantec
	
- Issue 3661:	fixed the calculation of base in PNGReadWriter>>copyPixelsGray: (floor vs ceil). Thanks Levente Uzonyi.'.
	self loadTogether: self script42 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/7/2011 17:52'!
update13043
	"self new update13043"
	self withUpdateLog: '- Issue 3683: Debugger context menu fix. Thanks Igor Stasenko.
- Fixing the workspace shifted menu. '.
	self loadTogether: self script43 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/7/2011 18:22'!
update13044
	"self new update13044"
	self withUpdateLog: '- funky Class comment for HTTPClient'.
	self loadTogether: self script44 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/10/2011 12:11'!
update13045
	"self new update13045"
	self withUpdateLog: '- Issue 3688:	Network primitives missing in the image. Thanks Jannik Laval'.
	self loadTogether: self script45 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/10/2011 15:07'!
update13046
	"self new update13046"
	self withUpdateLog: '- Issue 3659:	Task bar appearance does not make sense. Thanks Nick Alexander.
- Issue 3675:	ProcessBrowser>>cleanup
- Issue 3682:	multiple undo/redo is broken in 1.2 because of Ocompletion. Part two.'.
	self loadTogether: self script46 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/10/2011 15:58'!
update13047
	"self new update13047"
	
	"empty for the updates13 changed"! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/10/2011 16:09'!
update13048
	"self new update13048"
	self withUpdateLog: '[COTDC] 4 - RecategorizedEvent. Thanks Laurent Laffont and Benjamin van Ryseghem.'.
	self loadTogether: self script47 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/10/2011 17:40'!
update13049
	"self new update13049"
	self withUpdateLog: '- deprecate scope:....
- CompilerExceptionTest refactoring.'.
	self loadTogether: self script48 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 2/10/2011 18:21'!
update13050
	"self new update13050"
	self withUpdateLog: 'Added COTDC on StandardFonts'.
	self loadTogether: self script49 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/10/2011 20:43'!
update13051
	"self new update13051"
	self withUpdateLog: '- Issue 3583:	Shout should only be active in code panes. Thanks benjamin van ryseghem.
-  Issue 3689:	Transcript preference for #characterLimit.'.
	self loadTogether: self script50 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/12/2011 14:29'!
update13052
	"self new update13052"
	self withUpdateLog: '- Issue 3583:	beStyled and unStyled. 
- Issue 3696:	Default style loading problem. Thanks Alain Plantec.'.
	self loadTogether: self script51 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/12/2011 16:50'!
update13053
	"self new update13053"
	self withUpdateLog: '- Issue 3697:	UI Enhancements. Thanks Gary Chambers.
- Issue 3699:	Beeper beep raises MNU.
- Issue 1057:	SerialPlugin does not handle arbitrary nodes names. Thanks Severin and Serge.'.
	self loadTogether: self script52 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 2/13/2011 16:56'!
update13054
	"self new update13054"
	self withUpdateLog: 'COTDC
- 7. CodeAnnotationMorph - A.Plantec
- 8. WikiStyleHelpBuilder - L.Laffont'.
	self loadTogether: self script53 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/14/2011 13:22'!
update13055
	"self new update13055"
	self withUpdateLog: '- Issue 3703: cogitClass / interpreterClass. 
- Issue 3583: Shout should only be active in code panes. Thanks Benjamin van Ryseghem.'.
	self loadTogether: self script54 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/16/2011 10:20'!
update13056
	"self new update13056"
	self withUpdateLog: '- FixWorkspace1.3.1
- PrepareFixWorkspaceMenu.2
- FixWorkspaceMenu.2'.
	self loadTogether: self script55 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/16/2011 11:17'!
update13057
	"self new update13057"
	self withUpdateLog: '- Issue 3705:	UI Enhancements. Thanks Gary Chambers.'.
	self loadTogether: self script56 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/22/2011 15:41'!
update13058
	"self new update13058"
	self withUpdateLog: '- Issue 3708:	Selection text color enh. Thanks Alain Plantec'.
	self loadTogether: self script57 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/22/2011 17:27'!
update13059
	"self new update13059"
	self withUpdateLog: '- Issue 3727:	Fix Inspector Menu. Thanks Igor and Benjamin.
- Issue 3716:	Different return value for adoptInstance: depending on VM. Thanks Henrik Johanssen.
- Issue 3745:	Directly browse a selector in the Class if there is only a single matching Method. Thanks Camillo Bruni.
- Issue 3744:	Browse Items in the Inspector. Thanks Camillo Bruni.
'.
	self loadTogether: self script58 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/22/2011 17:49'!
update13060
	"self new update13060"
	self withUpdateLog: '-Issue 3746:	PluggableTextEditorMorph deprecation in 1.3. Thanks Alain Plantec.'.
	self loadTogether: self script59 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 2/22/2011 18:48'!
update13061
	"self new update13061"
	self withUpdateLog: '- Issue 3740:	Provide Settings to directly open the full Debugger View. Thanks Camillo Bruni.
- Issue 3739:	Show the currently selected Category, Class, Protocol and Selector in the Browser title. Thanks Camillo Bruni.'.
	self loadTogether: self script60 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 2/23/2011 20:31'!
update13062
	"self new update13062"
	self withUpdateLog: 'COTDC:
- 9. HTTPDownloadRequest - L.Laffont
- 10. DummyUIManager - L.Laffont
- 11. ColorMappingCanvas - I.Stasenko, L.Laffont
- 12. PluggableListMorphByItem - G.Chambers
- 13. NullEncoder - I.Stasenko
- 14. MCSnapshotReader - H.Johansen
- 15. PSMCPatchMorph - G.Polito
- 16. GoferReinitialize - L.Renggli'.
	self loadTogether: self script61 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 2/24/2011 20:25'!
update13063
	"self new update13063"
	self withUpdateLog: 'Issue 3749:	new TimeProfiler integration
Issue 3740:	Provide Settings to directly open the full Debugger View
Issue 3723:	The Finder tool does not alphabetize methods.
[Pharo-project] Browser class list/switches'.
	self loadTogether: self script62 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 2/24/2011 21:16'!
update13064
	"self new update13064"
	self withUpdateLog: 'Issue 3350:	Network Tests
Issue 3694:	Balloon message should be opaque for better readability'.
	self loadTogether: self script63 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'AlainPlantec 2/25/2011 15:27'!
update13065
	"self new update13065"
	self withUpdateLog: 'Issue 3755: help browser list highlight
Issue 3756: browser title '.
	self loadTogether: self script64 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'AlainPlantec 2/25/2011 17:21'!
update13066
	"self new update13066"
	self withUpdateLog: 'Issue 3759: Stragger -> stagger
Issue 3742: MorphTreeMorph keyStroke: send Event object instead of Character'.
	self loadTogether: self script65 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/1/2011 14:27'!
update13067
	"self new update13067"
	self withUpdateLog: '- Issue 3765:	fixed printPadded. Thanks David Lewis.
- Issue 3743:	Fix Finder UI (add shortcuts and more commands). Thanks Benjmain van Ryseghem.
-  Issue 3761:	overlappingPairsCollect: fails on OrderedCollections. Thanks guys :)
	 | collection | 
	collection := OrderedCollection withAll: #(1 2 3 4 5).
	collection overlappingPairsCollect: [ :a :b | a + b ].
-  Issue 3762:	Refactor TextEditor >> dispatchOn:. Thanks Camillo Bruni'.
	self loadTogether: self script66 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/1/2011 15:14'!
update13068
	"self new update13068"
	self withUpdateLog: 'Issue 3648:	A "Stratified" proxy in smalltalk'.
	self loadTogether: self script67 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/1/2011 21:35'!
update13069
	"self new update13069"
	self withUpdateLog: '- Issue 3737:	Behavior>>allSubclasses comment does not match actual implementation. 
- Issue 3704:	remove FakeClassPool adopt: and its senders. Thanks Nicolas Cellier for the idea.
- Issue 3691:	Cleaning by comparing SimpleMorphic and Morphic. Thanks Fernando Olivero for the feedback.'.
	self loadTogether: self script68 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/4/2011 14:31'!
update13070
	"self new update13070"
	self withUpdateLog: 'Issue 3783:	Point>>#printOn:
Issue 3781:	Finder version 30 does not report all selectors - 2 problems
Issue 3775:	FileList shouldnt inherit from StringHolder
Issue 3764:	Test runner: file out results sometimes disabled even with existing failures / errors.'.
	self loadTogether: self script69 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/4/2011 15:31'!
update13071
	"self new update13071"
	self withUpdateLog: 'Issue 1042:	documentation/help menu'.
	self loadTogether: self script70 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 3/4/2011 22:49'!
update13072
	"self new update13072"
	self withUpdateLog: 'COTDC integration
18 - SMxMorphicAlarm - N.Bouraqadi, L.Laffont, H.Johansen
19 - NaturalLanguageFormTranslator - G.Chambers
20 - Loader - N.Bouraqadi, S.Ducasse
21 - DictionaryInspector - Carlo, N.Bouraqadi
22 - EditableTextMorphAnnouncement - L.Laffont
23 - PopupChoiceDialogWindowWithMessage - L.Laffont
24 - DockingBarMorph - L.Laffont'.
	self loadTogether: self script71 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/6/2011 22:15'!
update13073
	"self new update13073"
	self withUpdateLog: '- Issue 3728:	Changed MenuMorph references to go through UIManager default menuClass. Thanks Fernando Olivero for reviewing the changes.'.
	self loadTogether: self script72 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/7/2011 16:35'!
update13074
	"self new update13074"
	self withUpdateLog: '-  Issue 3778:	cleaning cursor: and cursor. Part one. Thanks to Fernando Oliveiro for feedback and help.'.
	self loadTogether: self script73 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/7/2011 17:31'!
update13075
	"self new update13075"
	self withUpdateLog: '-  Issue 3778:	cleaning cursor: and cursor. Part two. Thanks to Fernando Oliveiro for feedback and help.'.
	self loadTogether: self script74 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/7/2011 22:44'!
update13076
	"self new update13076"
	self withUpdateLog: '- repackaged MouseWheelEvent
- moving AbstractResizerMorph overrides to polymorph extensions'.
	self loadTogether: self script75 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/8/2011 18:50'!
update13077
	"self new update13077"
	self withUpdateLog: '-  Issue 3791:	fit all windows to be visible. Thanks Jannik Laval'.
	self loadTogether: self script76 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/10/2011 16:00'!
update13078
	"self new update13078"
	self withUpdateLog: '- Issue 3728:	Changed MenuMorph references to go through UIManager default menuClass. Post Fix. Thanks Fernando Olivero
	
- Issue 3796:	Remove .pr references.
	
- Issue 3790:	minimise with no other un-collapsed windows.  Thanks Gary Chambers.'.
	self loadTogether: self script77 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/12/2011 11:46'!
update13079
	"self new update13079"
	self withUpdateLog: '- Issue 3600:	Enhancement : Refactorings and tests on Balloon-Collections. Thanks HJO :) and Henrik Johanssen.'.
	self loadTogether: self script78 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/12/2011 13:35'!
update13080
	"self new update13080"
	self withUpdateLog: '- FinderUI fixes. Thanks Benjamin van Ryseghem.
-  Issue 3807:	FileIn from FileContentsBrowser is broken when in presence of reorganize. Benjamin van Ryseghem.
- SyntaxError Compiler new evaluate: mistake.'.
	self loadTogether: self script79 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'SeedFxing 3/12/2011 14:30'!
update13081
	"self new update13081"
	self withUpdateLog: '- Issue 3283:	Symbol dependent on Scanner. part 1 and 2. 
- Removed UIThemePro.
- Issue 3299:	[Kernel Dependencies] Object Extension.'.
	self loadTogether: self script80 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/12/2011 15:11'!
update13082
	"self new update13082"
	self withUpdateLog: '- Issue 3074: Suggestion for Remodularisation -> SmalltalkImage. Thanks Nicolas Paez.
- Created System-SourceAndChangeFile
- Symbol part 3.
- Finder fix.'.
	self loadTogether: self script81 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/12/2011 16:07'!
update13083
	"self new update13083"
	self withUpdateLog: '-  Issue 3375:	PositionableStream remove dependence to Compiler. 
-  Issue 3283:	Symbol dependent on Scanner. Part Four.
-  Issue 3307:	[Kernel Dependencies] CompiledMethodTrailer>>#encodeUsingZip CompiledMethodTrailer>>#decodeZip
-  Issue 3810:	Methods of Traits are in the changesorter, but not the fileout'.
	self loadTogether: self script82 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/13/2011 12:03'!
update13084
	"self new update13084"
	self withUpdateLog: '- Issue 3311:	[Kernel Dependencies] Object / Compiler.
- Issue 3283:	Symbol dependent on Scanner. Part 5, 6 and 7.
- FinderUI fixes.
New version '.
	self loadTogether: self script83 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/13/2011 12:20'!
update13085
	"self new update13085"
	self withUpdateLog: '- Remove Object>>undo. 
- Issue 3312: [Kernel Dependencies] BlockClosure >> #decompile.
- Issue 3313:	[Kernel Dependencies] UndefinedObject / Compiler.
'.
	self loadTogether: self script84 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/13/2011 12:52'!
update13086
	"self new update13086"
	self withUpdateLog: '- Added test packages
- Removed PharoCorePackageDependencyTests'.
	self loadTogether: self script85 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/14/2011 12:40'!
update13087
	"self new update13087"
	self withUpdateLog: '-  Issue 3814:	Weak announcements refinement. Preparation 	Announcements-Core-LukasRenggli.12
	Announcements-Tests-Core-LukasRenggli.4

- Issue 3815:	Filing in Class comments raises an error. '.
	self loadTogether: self script86 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/14/2011 13:01'!
update13088
	"self new update13088"
	self withUpdateLog: '- Issue 3811:	Extending MessageSend protocol with cull: and value: protocol. Thanks Igor and Henrik.'.
	self loadTogether: self script87 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/14/2011 13:17'!
update13089
	"self new update13089"
	self withUpdateLog: '- Issue 3814:	Weak announcements refinement. Part one. Thanks Igor and Henrik. + Announcer allInstances do:[:each | each migrateSubscriptions ]'.
	self loadTogether: self script88 merge: false.
	Announcer allInstances do: [:each | each migrateSubscriptions ].
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 3/14/2011 13:28'!
update13090
	"self new update13090"
	self withUpdateLog: '- Issue 3814:	Weak announcements refinement. Part two.'.
	self loadTogether: self script89 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/14/2011 14:49'!
update13091
	"self new update13091"
	self withUpdateLog: '- fixing isHeadless to cope with mac vm not handling correctly vm parameters.'.
	self loadTogether: self script90 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/15/2011 14:21'!
update13092
	"self new update13092"
	self withUpdateLog: 'Issue 3798:	FilePath>>coverter is a typo and unused
Issue 3457:	Cannot show new CompiledMethods asString
'.
	self loadTogether: self script91 merge: false.
	ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 3/15/2011 20:56'!
update13093
	"self new update13093"
	self withUpdateLog: 'COTDC integration
25 - PolymorphSystemSettings - L.Laffont
26 - PickAFileToWriteNotification - Carlo, F.Olivero
27 - DropEvent - F.Olivero, R.Moran
28 - ImmAbstractPlatform - H.Johansen
29 - EventSensorConstants - I.Stasenko
30 - StepMessage - L.Laffont
31 - PreDebugWindow - G.Polito'.
	self loadTogether: self script92 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/18/2011 09:29'!
update13094
	"self new update13094"
	self withUpdateLog: '- Issue 3792:	PluggableListMorph with a wrapper for display. Thanks Benjamin van Ryseghem.
'.
	self loadTogether: self script93 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/18/2011 12:46'!
update13095
	"self new update13095"
	self withUpdateLog: 'Issue 3820:	TextConstants change to SharedPool breaks external code using at: message
Issue 3823:	MorphTreeMorph shift click multi-highlight even if your tree is single selection
Issue 1507:	is LocatedMethod needed?
Issue 3824:	Finder: add a fancy icon
'.
	self loadTogether: self script94 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/18/2011 13:32'!
update13096
	"self new update13096"
	self withUpdateLog: 'Issue 3785:	WeakOrderedCollection from Squeak required for Magma on Pharo 1.2 and 1.3
Issue 3826:	remove class LocatedMethod
'.
	self loadTogether: self script95 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/18/2011 21:27'!
update13097
	"self new update13097"
	self withUpdateLog: 'Issue 3828:	SimpleMorphic overrides system method'.
	self loadTogether: self script96 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/20/2011 11:34'!
update13098
	"self new update13098"
	self withUpdateLog: '- Issue 3836:	superfluous packageInfo respondsTo: #overriddenMethods. 
- Issue 3835: Finder and RecentSubmissions new versions. Thanks Benjamin van Ryseghem.
- Issue 3833:	Morph and MorphTreeMorph fixes. Thanks Benjamin van Ryseghem.
-  Issue 3787:	Project current setChangeSet: aChangeSet. Thanks Marcus Denker.'.
	self loadTogether: self script97 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/21/2011 11:22'!
update13099
	"self new update13099"
	self withUpdateLog: ' Issue 3834:	Add support for Threaded VMs in Process'.
	self loadTogether: self script98 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/21/2011 14:40'!
update13100
	"self new update13100"
	self withUpdateLog: 'Issue 3591:	Implementors of #listMorph place it in different (or no) category
Issue 3605:	[ENH]: Added #saveTo: method to MIMEDocument (renamed to saveToFile:)'.
	self loadTogether: self script99 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/22/2011 13:42'!
update13101
	"self new update13101"
	self withUpdateLog: '- Cleaning Polymorph overrides. Part one'.
	self loadTogether: self script100 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/22/2011 14:19'!
update13102
	"self new update13102"
	self withUpdateLog: '- Cleaning Polymorph overrides. Part two'.
	self loadTogether: self script101 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/22/2011 17:50'!
update13103
	"self new update13103"
	self withUpdateLog: 'Issue 3821:	makeStrong/makeWeak contains a bug
Issue 3843:	isHealthy for HasedCollection
Issue 3840:	ivar errorHandler in Process seems to be unused'.
	self loadTogether: self script102 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/22/2011 20:57'!
update13104
	"self new update13104"
	self withUpdateLog: '- Polymorph override cleaning. Part three'.
	self loadTogether: self script103 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/22/2011 21:48'!
update13105
	"self new update13105"
	self withUpdateLog: '- Remove Arc Line Path CruverFitter.... ST-80-Path'.
	self loadTogether: self script104 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/23/2011 15:19'!
update13106
	"self new update13106"
	self withUpdateLog: 'Issue 3844:	Utilities is in StartupList
Issue 2488:	LargeInteger ln overflows
Issue 3847:	The absolute value of a negativeZero should behave like a positive zero
Issue 3841:	clean Project more: remove Locale and project parameters'.
	self loadTogether: self script105 merge: false.
	Smalltalk removeFromStartUpList: Utilities.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/2/2011 13:53'!
update13107
	"self new update13107"
	self withUpdateLog: 'Issue 3768:	Deprecate String >> get/putInteger32:
Issue 1765:	JPEGReadWriter>>#decompressionTest should be made into a Sunit Test
Issue 2240:	CondenseChange Trait Tests
Issue 2786:	Mixed concerns on Object>>saveOnFile
Issue 3638:	look for sender of etoyCleaningLeftToDo
Issue 3701:	FloatArray>>dot: is defined in plugin but not at the image level
Issue 3667:	ThreadSafeTranscript does not understand crtab and crtab:
'.
	self loadTogether: self script106 merge: false.
	"ExternalSettings registeredClients remove: ServerDirectory.
ExternalSettings registeredClients remove: HTTPSocket."
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/24/2011 17:08'!
update13108
	"self new update13108"
	self withUpdateLog: 'Issue 3862:	Move ParagraphEditor and TextMorphEditor to Deprecated13 package
Issue 3854:	Move taskbar methods from Project to PasteUpMorph
Issue 3856:	ActionSequence is unused
Issue 3855:	Clean up Imports
'.
	self loadTogether: self script107 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/25/2011 12:36'!
update13109
	"self new update13109"
	self withUpdateLog: 'Issue 3863:	packages cleanup needed'.
	self loadTogether: self script108 merge: false.
	(MCPackage named: 'Collections-Tests-Strings') workingCopy unregister.
(MCPackage named: 'System-SourcesAndChangeFile') workingCopy unregister.
(MCPackage named: 'Collections-Tests-Text') workingCopy unregister.
(MCPackage named: 'VB') workingCopy unregister.
(MCPackage named: 'Shout') workingCopy unregister.
ScriptLoader new addHomeRepositoryToAllPackages.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 4/3/2011 22:38'!
update13110
	"self new update13110"
	self withUpdateLog: '- Issue 3881:	Problem with Inst var refs.... Thanks Benjamin van Ryseghem.
- Issue 3879:	Wipe out positional arguments cruft from compiler. Thanks Igor Stasenko.
-  Issue 3859:	Pluggin control. Thanks Igor Stasenko.
- Issue 3715:	Workspace shouting after switching between shout/unshout. Thanks Benjamin van Ryseghem.
- Cleaning MCPackageManager. 
- Fixing some as yet unclassified categories.'.
	self loadTogether: self script109 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/25/2011 18:59'!
update13111
	"self new update13111"
	self withUpdateLog: '- Issue 3880:	Balloon Tests not categorized/commented in 1.3. Thanks Torsten Bergmann.
- Issue 3876:	SqNumberParserTest>>testFloatGradualUnderflow has an odd condition. Thanks Nicolas Cellier and Dale Henrichs.
-  Issue 3875:	Merge minor NumberParser refactorings from Squeak.   Thanks Nicolas Cellier 
- Issue 3850:	remove HTTPServerDirectory PseudoFileStream. Thanks Marcus Denker
- Issue 3718:	Color class>>wheel: should be (back) on class side. Thanks Marcus Denker'.
	self loadTogether: self script110 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/26/2011 09:53'!
update13112
	"self new update13112"
	self withUpdateLog: '- Issue 2704:	Tests for broken withNoLineLongerThan: behavior. Thanks Nicolas Cellier and Andreas Raab.
- Issue 3864:	[Failing Test] 1.3 ImageSegmentTestExport. 
- Issue 3341:	use #= for integer comparison instead of #==. Kernel Part.
- Less overrides in the system: around 100 left. :('.
	self loadTogether: self script111 merge: false.
	Smalltalk fixObsoleteReferences.
BalloonEngine initialize.
DataStream initialize.
DeflateStream initialize.
FastInflateStream initialize.
ZipConstants initialize.
ZipWriteStream initialize.
PNGReadWriter initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/28/2011 17:38'!
update13113
	"self new update13113"
	self withUpdateLog: 'Issue 2450:	halt in TTFontReader >>processCompositeGlyph:contours:from:
Issue 3866:	[Failing Test] 1.3 ReleaseTest.testUndeclared
Issue 3889:	move FontSubstitutionDuringLoading from System-GUISupport to Graphics-Fonts
Issue 3891:	move FreeTypeSubPixelAntiAliasedGlyphRenderer to FreeType-GlyphRendering
Issue 3890:	move ViewHierarchyExplorer to Tools-Explorer
Issue 3894:	MenuMorph add:
Issue 3867:	[Failing Test] 1.3 FloatTest.testPrintPaddedWithTo
Issue 3886:	Move PointerFinder to Deprecated13'.
	self loadTogether: self script112 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/28/2011 18:19'!
update13114
	"self new update13114"
	self withUpdateLog: 'Issue 3893: PluggableListMorphOfMany better implementation of autoDeselect:
Issue 3897:	clean tiles related icon methods
Issue 3895:	DialogItemsChooser-BenjaminVanRyseghem.13
Issue 3882:	Cant scale imported graphic
Issue 3838:	Cleaning MCPackageLoader
Issue 3793:	MorphTreeMorph >> #addSelectedNodeItem:
Issue 3883:	Move Mime related classes from MimeConverter to Network-MIME'.
	self loadTogether: self script113 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/28/2011 21:58'!
update13115
	"self new update13115"
	self withUpdateLog: 'Issue 3893:	PluggableListMorphOfMany better implementation of autoDeselect:
Issue 3884:	Cleaning st80 Paragraph
Issue 3887:	Clean Project more
Issue 3681:	[Failing Test] Tests.Release.ReleaseTest.testObsoleteClasses'.
	self loadTogether: self script114 merge: false.
	BalloonEngine initialize.
DataStream initialize.
DeflateStream initialize.
FastInflateStream initialize.
ZipConstants initialize.
ZipWriteStream initialize.
PNGReadWriter initialize.
ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/29/2011 09:33'!
update13116
	"self new update13116"
	self withUpdateLog: '- Issue 3892:	clean AbstractHierarchicalList. 
- Issue 3899:	clean up #maybeDuplicateMorph:. 
- Issue 3888:	Move Digital Signatur code to System-Hashing package. 
- Issue 3898:	Remove some dead code from PasteUpMorph.
- Issue 3779:	isUnicodeStringWithCJK returns false on a string containing Kanji'.
	self loadTogether: self script115 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/29/2011 17:58'!
update13117
	"self new update13117"
	self withUpdateLog: '- Issue 3908:	Fix for pool variables references. Thanks Igor Stasenko.
- Issue 3907:	SystemNavigation doesn t display the name of the selector when it asks for method removal. Thanks Benjamin Ryseghem.'.
	self loadTogether: self script116 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/29/2011 22:07'!
update13118
	"self new update13118"
	self withUpdateLog: '-  Issue 3429:	Better Number performance. Thanks Levente and Nicolas Cellier.
- Issue 3845:	Polymorph extension shortSummary is not programmed the object way. Thanks Nicolas Cellier.
-  Issue 3902:	Text field converter refactoring. Thanks Gary Chambers.
-  Issue 3713:	Additional obsolete methods. Thanks Edmond 
-  Issue 3878:	#enableTextChange selector name is misleading, i propose changing the name to #canChangeText. Thanks Fernando Olivero.'.
	self loadTogether: self script117 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/31/2011 12:36'!
update13119
	"self new update13119"
	self withUpdateLog: 'Issue 3913:	Fix in PluggableListMorph hierarchy
Issue 3736:	new Transcript from CUIS'.
	self loadTogether: self script118 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/31/2011 12:54'!
update13120
	"self new update13120"
	self withUpdateLog: 'Issue 3584:	ToDo: remove DisplayText class
Issue 3910:	-0.01s2 printString is loosing its sign
Issue 3906:	SharedPool should be moved to Kernel'.
	self loadTogether: self script119 merge: false.
	(MCPackage named: 'System-Digital Signatures') workingCopy unregister.
(MCPackage named: 'MimeConverter') workingCopy unregister.
(MCPackage named: 'System-GUISupport') workingCopy unregister.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 3/31/2011 13:14'!
update13121
	"self new update13121"
	self withUpdateLog: 'Issue 3900:	FileDirectory>>withAllSubdirectoriesCollect:
Issue 3911:	Change updater to allow updating a release image
Issue 3915:	Make all requests to open comparison morph (DiffMorph) go thru UIManager'.
	self loadTogether: self script120 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/31/2011 16:15'!
update13122
	"self new update13122"
	self withUpdateLog: '- Issue 3924:	remove #scopeFor:from:envtAndPathIfFound:. 
- Issue 3925:	PluggableIconListMorph improvment. Thanks Benjamin van ryseghem.'.
	self loadTogether: self script121 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 3/31/2011 21:12'!
update13123
	"self new update13123"
	self withUpdateLog: 'COTDC integration
- 32 - MCScanner - L.Renggli, L.Laffont
- 33 - StrikeFontSet - HwaJong Oh, L.Laffont
- 34 - MCStWriter, MCStReader - L.Laffont
- 35 - MCPackageCache - S.Ducasse
- 36 - MCDefinitionIndex - S.Ducasse
- 37 - MCPatcher - HJ.Oh
- 38 - PathShape, Polygon - G.Chambers, L.Laffont
- 39 - EditableDropListMorph - L.Laffont'.
	self loadTogether: self script122 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 3/31/2011 22:39'!
update13124
	"self new update13124"
	self withUpdateLog: '- Issue 3928:	Add reciprocalModulo: support in Kernel. Thanks Nicolas Cellier
-  Issue 3926:	MorphTreeMorph autoSelet. Thanks Benjamin van Ryseghem.
- Lesser Polymorph overrides'.
	self loadTogether: self script123 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/1/2011 13:30'!
update13125
	"self new update13125"
	self withUpdateLog: 'Issue 3922:	Add ClassHierarchy Checks
Issue 3920:	String has extension for *graphics
Issue 3896:	1.3 core has wrong theme enabled
Issue 3769:	Printing an object depends on #isKindOf:'.
	self loadTogether: self script124 merge: false.
	GLMUITheme beCurrent.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/1/2011 15:01'!
update13126
	"self new update13126"
	self withUpdateLog: 'Issue 3677:	A to:do: loop cannot modify the limit inside the block
Issue 3930:	PickAFileToWriteNotification is not used --> move to Deprecated13
Issue 3929:	Package Filter for MC based repo browser
Issue 3918:	Package ST80 needs to be cleaned
Issue 3904:	The Deprecated11 package should be unloaded in 1.3
Issue 3932:	Delete package: FreeTypeSubPixelAntiAliasing
Issue 3919:	Pckage System-Pools needs to be removed'.
	self loadTogether: self script125 merge: false.
	(MCPackage named: 'Deprecated11') workingCopy unload.
(MCPackage named: 'ST80') workingCopy unregister.
(MCPackage named: 'FreeTypeSubPixelAntiAliasing') workingCopy unregister.
(MCPackage named: 'System-Pools') workingCopy unregister.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/1/2011 17:30'!
update13127
	"self new update13127"
	self withUpdateLog: 'Issue 3934:	Add isDisplayed in SystemWindow
Issue 3933:	Better behavior for selection in PluggableListMorphOfMany and PluggableMorphListMorphOfMany
Issue 2360:	[Failing Test] nil out locals in a block if readBeforeWritten (pre req)
'.
	self loadTogether: self script126 merge: false.
	MessageNode initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/1/2011 17:41'!
update13128
	"self new update13128"
	self withUpdateLog: 'Issue 2360:	[Failing Test] nil out locals in a block if readBeforeWritten (second part)'.
	self loadTogether: self script127 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/1/2011 17:49'!
update13129
	"self new update13129"
	self withUpdateLog: 'Issue 2360:	[Failing Test] nil out locals in a block if readBeforeWritten (third part)'.
	self loadTogether: self script128 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/2/2011 11:58'!
update13130
	"self new update13130"
	self withUpdateLog: 'Issue 3921:	due to *graphics package, we lost some string changes
Issue 3938:	Fix ugly flashing in list morph
Issue 3854:	Move taskbar methods from Project to PasteUpMorph
Issue 3939:	Small DSA refactorings from squeak	
'.
	self loadTogether: self script129 merge: false.
	Compiler recompileAll.
ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 4/3/2011 22:43'!
update13131
	"self new update13131"
	self withUpdateLog: '- Issue 3949:	Coverage for Cog. Thanks Lukas Renggli.
- Issue 3947:	remove #floodFill:. Thanks Marcus Denker.
- Issue 3946:	remove some more uniclasses/player related code. Thanks Marcus Denker.
- Issue 3945:	Remove squeakland plugin methods from SystemVersion. Thanks Marcus Denker.
-  Issue 3944:	ClassHierarchyTest needs to be moved to KernelTests package. Thanks Marcus Denker.
- Removed SoftSqueak Theme. Repackage GLMTheme - Rename them.'.
	self loadTogether: self script130 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 4/5/2011 14:22'!
update13132
	"self new update13132"
	self withUpdateLog: '- Issue 3953:	add #ensureCr to new transcript
- fix world menu '.
	self loadTogether: self script131 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/5/2011 16:39'!
update13133
	"self new update13133"
	self withUpdateLog: 'Issue 3955:	Better implementation of the MorphTreeMorph auto select
Issue 3956:	Better implementation of the PluggableListMorphs auto select
Issue 3964:	Enabling double click on PluggableListMorphOfMany
Issue 3105:	DeepCopier warnIverNotCopiedIn:sel: dependent on ToolSet'.
	self loadTogether: self script132 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/7/2011 13:03'!
update13134
	"self new update13134"
	self withUpdateLog: 'Issue 3959:	A little dead code removal SmalltalkImage
Issue 3962:	More cleanup of PasteUpMorph
Issue 2561:	findTokens: String lf , String cr
Issue 3966:	String>>lines misses tests
'.
	self loadTogether: self script133 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/7/2011 13:54'!
update13135
	"self new update13135"
	self withUpdateLog: 'Issue 3969:	MorphTreeMorph performance
Issue 3943:	remove ExternalSettings from MC
- clean left over temps compression code in CompiledMethod (as its in the Trailer for a long time)'.
	self loadTogether: self script134 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/8/2011 15:13'!
update13136
	"self new update13136"
	self withUpdateLog: 'Issue 3969:	MorphTreeMorph performance
Issue 3870:	[Failing Test] 1.3 KernelTests.Methods.CompiledMethodTest.testNew'.
	self loadTogether: self script135 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/8/2011 22:50'!
update13137
	"self new update13137"
	self withUpdateLog: 'Issue 3973:	remove TextStyleFontSelectorDialogWindow (deprecated)
Issue 3976:	Fix double entry Apperance in Settings
Issue 3975:	References to ivars shortcut
'.
	self loadTogether: self script136 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/9/2011 22:47'!
update13138
	"self new update13138"
	"Smalltalk removeFromShutDownList: ExternalSettings.
Smalltalk removeFromStartUpList: ExternalSettings."
	self withUpdateLog: 'Issue 3849:	ExternalSettings should be cleaned
Issue 2559:	Senders of #ifNotNil: do not show'.
	self loadTogether: self script137 merge: false.
	Compiler recompileAll.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/10/2011 17:03'!
update13139
	"self new update13139"
	self withUpdateLog: 'Issue 3979:	Fixing an undeclare ref in ScriptLoader
Issue 3941:	Paragraph (deprecated) has lots of refs to undefined temps
Issue 3958:	Remove embedded snapshotting (image level)'.
	self loadTogether: self script138 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/11/2011 13:33'!
update13140
	"self new update13140"
	self withUpdateLog: 'Issue 3977:	Undeclared vars in MorphTreeMorp
Issue 3931:	Move all Exceptions-Kernel to Kernel-Exceptions'.
	self loadTogether: self script139 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/11/2011 17:53'!
update13141
	"self new update13141"
	self withUpdateLog: 'Issue 3988:	Debugger cannot open because of Decompiler assertion failure
Issue 3980:	TestResource fails to makeAvailable an never recovers
Issue 3987:	Use specific KeyNotFoundError in Dictionaries
Issue 2703:	Unicode experiments of nicolas cellier on squeak'.
	self loadTogether: self script140 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 4/11/2011 22:40'!
update13142
	"self new update13142"
	self withUpdateLog: '- continued to merged ploymoprh overrides
- Repackaged SUnit
- Use new Glamour refactored code but to avoid problems to Doru renamed it into BluePharo - should remove the PharoUITheme. We should migrate the orange look to be a subclass of BlueUITheme

Stef'.
	self loadTogether: self script141 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/12/2011 09:06'!
update13143
	"self new update13143"
	self withUpdateLog: 'Issue 3989:	Fix the scrollToView method
Issue 3800:	StaticForm can be removed
Issue 3960:	Catch all: Remove experimental + ancient backward compatibility code'.
	self loadTogether: self script142 merge: false.
	HandMorph initialize.
SMxHandMorph initialize.
(MCPackage named: 'Exceptions') workingCopy unregister.
(MCPackage named: 'Glamour-Morphic-Theme') workingCopy unregister.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/12/2011 10:08'!
update13144
	"self new update13144"
	self withUpdateLog: 'Issue 3994:	#ifUnknownAuthorUse:during: needed by Hudson testrunner
Issue 3993:	Undeclared SHTextStylerST80 in BlueUITheme>>setPreferredShoutColors
Issue 3983:	TestCase assertions are in accessing protocol
'.
	self loadTogether: self script143 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/12/2011 22:48'!
update13145
	"self new update13145"
	self withUpdateLog: 'Issue 4000:	Little improvement in MenuMorph
Issue 3998:	Cleanup MVC compatibility methods in Displayscanner
Issue 4001:	clean more unused postscript canvas methods'.
	self loadTogether: self script144 merge: false.
	World initializeDesktopCommandKeySelectors.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'StephaneDucasse 4/13/2011 09:18'!
update13146
	"self new update13146"
	self withUpdateLog: '- Issue 3991:	use them instead of UITheme current. Thanks Fernando Olivero. You were faster than me on this one but this is cool since I could review the code faster.'.
	self loadTogether: self script145 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/18/2011 11:01'!
update13147
	"self new update13147"
	"AutoStart deinstall."
	self withUpdateLog: 'Issue 3818:	CommandLine Manager
(some cleanup of Undeclared AutoStart will be needed later)'.
	self loadTogether: self script146 merge: false.
	CommandLine initialize.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/13/2011 15:13'!
update13148
	"self new update13148"
	self withUpdateLog: 'Issue 4003:	Build of Core 1.3 broken because of integration of 13147'.
	self loadTogether: self script147 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/14/2011 11:35'!
update13149
	"self new update13149"
	self withUpdateLog: 'Issue 3986:	Bug with Delay during clock rollover
Issue 4012:	Explore It crashes when selected using mouse
Issue 4010:	References to it nor working in Inspector
Issue 4008:	DNU on opening inspector with enabled taskbar
Issue 4006:	Some UI improvement
Issue 4007:	Taskbar disappeared
Issue 4013:	DNU ObjectExlorer with taskbar enabled'.
	self loadTogether: self script148 merge: false.
	World showWorldTaskbar: true.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/14/2011 14:11'!
update13150
	"self new update13150"
	self withUpdateLog: 'Issue 4014:	DNU for TestRunner because of #theme
Issue 4011:	Finder: self is not bound to class'.
	self loadTogether: self script149 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/14/2011 15:50'!
update13151
	"self new update13151"
	self withUpdateLog: 'Issue 4020:	Improve cleanUpForRelease and cleanUpForProduction
Issue 4017:	CommandLine>>#initialize should not reset registrations
Issue 4015:	Fix in SmalltalkEditor
Issue 3999:	Add More Explicit Error Classes for Collections
- Deprecate FillInTheBlankMorph'.
	self loadTogether: self script150 merge: false.
	ScriptLoader new cleanUpForRelease.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/15/2011 10:42'!
update13152
	"self new update13152"
	self withUpdateLog: 'Issue 4015:	Fix in SmalltalkEditor
Issue 4005:	Disconnect SecurityManager'.
	self loadTogether: self script151 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/15/2011 14:00'!
update13153
	"self new update13153"
	self withUpdateLog: 'Issue 4025:	MethodFinder should be moved to Finder-Core
Issue 3868:	[Failing Test] 1.3 SocketTest
Issue 3497:	Monticello Browser, +slice doesnt validate for not selecting any package
Issue 3872:	[Failing Test] 1.3 HttpUrlTest.testHttps'.
	self loadTogether: self script152 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 4/15/2011 15:01'!
update13154
	"self new update13154"
	self withUpdateLog: '- added collections-atomic'.
	self loadTogether: self script153 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 4/15/2011 15:16'!
update13155
	"self new update13155"
	self withUpdateLog: '- use WaitfreeQueue for InputEventSensor'.
	self loadTogether: self script154 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'IgorStasenko 4/15/2011 15:41'!
update13156
	"self new update13156"
	self withUpdateLog: '- fixed theme for File browser tool
- starting integration of ToolsRegistry'.
	self loadTogether: self script155 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/15/2011 16:21'!
update13157
	"self new update13157"
	self withUpdateLog: 'Issue 3871:	[Failing Test] 1.3 ReduceTest.testReduceCollection3Arguments
Issue 3869:	[Failing Test] 1.3 CompilerExceptionsTest
Issue 3874:	[Failing Test] 1.3 BlockClosureTest'.
	self loadTogether: self script156 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'LaurentLaffont 4/15/2011 20:25'!
update13158
	"self new update13158"
	self withUpdateLog: 'COTDC Integration:
40 - PasswordDialogWindow - L.Laffont
41 - NonReentrantWeakMessageSend + ExclusiveWeakMessageSend - H.Johansen
42 - ExpanderMorphContracted - G.Chambers
43 - FreeTypeFontSelectorDialogWindow - L.Laffont
44 - ColorChanged - L.Laffont
45 - TestCoverage - L.Laffont
46 - SUnitUnloader - S.V.Caekenberghe
47 - TAssertable - M.M.Peck
48 - ClassFactoryForTestCase - A.Bergel'.
	self loadTogether: self script157 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/16/2011 19:14'!
update13159
	"self new update13159"
	self withUpdateLog: 'Issue 4031:	Remove Mail to list in ChangeSorter
Issue 4030:	defaultBackgroundColor should not use self theme
Issue 3872:	[Failing Test] 1.3 HttpUrlTest.testHttps
Issue 3598:	[Failing Test]Tests.Compiler.CompilerTest.testNotInteractiveInBlockTempArgumentShadowing
Issue 3981:	#<= on SourcedMethodReference is very slow'.
	self loadTogether: self script158 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/18/2011 10:14'!
update13160
	"self new update13160"
	self withUpdateLog: 'Issue 4040:	SystemNavigation allClassesDo: should do it via environment
Issue 4035:	on #cleanUpForRelease, clean changeset at the end again
Issue 4034:	Deprecate TranslucentProgressMorrph + some dead code removal'.
	self loadTogether: self script159 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/18/2011 12:54'!
update13161
	"self new update13161"
	self withUpdateLog: 'Issue 3990:	2 dependencies removed from ToolBuilder: PluggableMenuSpec & PluggableMenuItemSpec
Issue 4045:	Failing Test: SystemNavigationOnNewlyCreatedEnvironmentTest >> #testAllReferencesToPool
Issue 4044:	Failing test: SystemVersionTest>>#testMajorMinor
Issue 4043:	Undeclared NoSuchElementError
Issue 4004:	Obsolete class references to AutoStart
Issue 4029:	DomainError and NaNException'.
	self loadTogether: self script160 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/18/2011 17:09'!
update13162
	"self new update13162"
	self withUpdateLog: '-> cleanup tests
-> Browser class>>#cleanUp should not re-gegister browser
-> add repos to all packages'.
	self loadTogether: self script161 merge: false.
	ScriptLoader new addHomeRepositoryToAllPackages.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/19/2011 09:50'!
update13163
	"self new update13163"
	self withUpdateLog: 'Issue 4052:	OBDefinition has reference to FakeClassPool (added to Deprecated13)
Issue 4048:	ExceptionDescriptionAndComments
Issue 4047:	NotFound-CollectionIsEmpty-SizeMismatch
Issue 3968:	ByteArray>>#asInteger
Issue 4002:	AbstractLauncher needs to be removed'.
	self loadTogether: self script162 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/19/2011 23:40'!
update13164
	"self new update13164"
	self withUpdateLog: 'Issue 4060:	KeyNotFoundAndValueNotFound
Issue 4059:	Fixed #cleanUpForRelease to not call #cleanUp on all classes but use Smalltalk>>#cleanUp: ...
Issue 4053:	 remove empty package system-launcher

'.
	self loadTogether: self script163 merge: false.
	(MCPackage named: 'System-Launcher') workingCopy unregister.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/20/2011 10:51'!
update13165
	"self new update13165"
	self withUpdateLog: 'Issue 4058:	Character printOn: storeOn: are inconsistent for Character delete
Issue 4062:	Unpackaged Code
Issue 4061:	External semaphore table size accessors for Cog

'.
	self loadTogether: self script164 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/20/2011 20:26'!
update13166
	"self new update13166"
	self withUpdateLog: 'Issue 4063:	SelectorExceptionSubclassResponsibilityPrimitiveFailedShouldBeImplementedShouldNotImplement
Issue 4019:	It should be possible to call CodeLoader>>initialize multiple times
Issue 2841:	Heap equality should be transitive
'.
	self loadTogether: self script165 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/20/2011 20:41'!
update13167
	"self new update13167"
	self withUpdateLog: 'Issue 4019:	It should be possible to call CodeLoader>>initialize multiple times
Issue 4033:	clean up startup/shutdownlist adding, add before
'.
	self loadTogether: self script166 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/21/2011 10:22'!
update13168
	"self new update13168"
	Smalltalk removeFromStartUpList: (Smalltalk globals classNamed: #SecurityManager).
.
	self withUpdateLog: 'Issue 3996:	alt+k opens a StringHolder and not a workspace
Issue 1853:	NetNameResolver localHostAddress returns public or private address instead of loopback address.
Issue 3188:	do we need SecurityManager?'.
	self loadTogether: self script167 merge: false.
	World initializeDesktopCommandKeySelectors.
.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/21/2011 18:28'!
update13169
	"self new update13169"
	self withUpdateLog: 'Issue 2927:	formFromServerFile -> a better little helper
Issue 3431:	Faster traitNames
Issue 4066:	MNU when saving in monticello and no package is selected'.
	self loadTogether: self script168 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/21/2011 19:20'!
update13170
	"self new update13170"
	self withUpdateLog: 'Issue 4071:	Failign Tests: GoferApiTest.testRepositoryErrors
Issue 4070:	Cleaned UIFinder model and package structure
Issue 4064:	TextEditor little refactor over Keystroke handling
'.
	self loadTogether: self script169 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/23/2011 10:13'!
update13171
	"self new update13171"
	self withUpdateLog: 'Issue 4074:	Catchall for trivialities
Issue 4037:	Source search in Finder should be case insensitive'.
	self loadTogether: self script170 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/25/2011 10:18'!
update13172
	"self new update13172"
	self withUpdateLog: 'Issue 3088:	MNU Text>>withBlanksTrimmed
Issue 4091:	Remove Socket primitiveOnlySupportsOneSemaphore
Issue 4084:	Adding comments to announcer
Issue 4083:	fix full image text search (typo)
Issue 4068:	SubscriptOutOfBounds
Issue 4081:	MessageNotUnderstood: Transcript class>>theme
Issue 4079:	add hasSubscriber: to Announcer'.
	self loadTogether: self script171 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'pharo - updates' stamp: 'MarcusDenker 4/26/2011 22:53'!
update13173
	"self new update13173"
	self withUpdateLog: 'Issue 4094:	Object>>chooseUniqueClassName can be removed
Issue 2177:	Generalize stream protocol #readInto:startingAt:count:'.
	self loadTogether: self script172 merge: false.
	self flushCaches.
! !

!ScriptLoader methodsFor: 'elementary steps' stamp: 'StephaneDucasse 1/31/2011 22:22'!
updateUpdatesList: aString
	"ScriptLoader new updateUpdatesList: 'cleanUpMethods'"
	
	| str |
	str := FileDirectory default oldFileNamed: self updatesListFileName.
	[	str
			setToEnd;
			cr;
			nextPutAll: self currentUpdateVersionNumber asString;
			nextPutAll: '-Pha-', aString, '.cs' ]
		ensure: [ str close ]! !

!ScriptLoader methodsFor: 'private' stamp: 'StephaneDucasse 2/10/2011 15:40'!
updatesListFileName

	^ 'updates', (SystemVersion current majorMinor:''), '.list'! !

!ScriptLoader methodsFor: 'menu integration actions' stamp: 'lr 3/14/2010 21:13'!
verifyNewUpdate
	self repository: self class defaultMCWaitingFolder.
	self class loadLatestPackage: 'ScriptLoader' fromRepository: self repository.
	self perform: ('update' , self getLatestUpdateNumber asString) asSymbol.
	(self confirm: 'Completed loading the new update. Run all test now?')
		ifTrue: [ 
			Author fullName: 'tester'.
			Smalltalk globals at: #TestRunner ifPresent: [ :class | class open model runAll ] ]! !

!ScriptLoader methodsFor: 'private' stamp: 'al 11/1/2008 18:19'!
waitingFolderMCZFiles
	^ self class defaultMCWaitingFolder allFileNames
		reject: [:each | each =  '.DS_Store']! !

!ScriptLoader methodsFor: 'log' stamp: 'sd 3/24/2008 16:45'!
withUpdateLog: aString

	self logStream nextPutAll: ' ------------------------------------------------------' ; cr.
	self logStream nextPutAll: thisContext sender selector asString. 
	self logStream cr; nextPutAll: aString ; cr.! !

!ScriptLoader methodsFor: 'fixing stream' stamp: 'sd 3/24/2008 17:31'!
workingCopyFromPackageName: aString
	"self new workingCopyFromPackageName: '39Deprecated' "
	
	|pa|
	pa := MCPackage named: aString.
	^ pa workingCopy 
	! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'sd 7/8/2006 18:20'!
writeCS: extensionAndNumber forUpdate: updateNumber
	"ScriptLoader new writeCS: '-sd.210' forUpdate: 7037"
	
	self writeCS: extensionAndNumber forUpdate: updateNumber withName: 'changeMe'! !

!ScriptLoader methodsFor: 'generate scripts/methods' stamp: 'StephaneDucasse 2/25/2010 18:09'!
writeCS: extensionAndNumber forUpdate: updateNumber withName: aSt
	"ScriptLoader new writeCS: '-md.2929' forUpdate: 7049 withName: 'cleanUpMethods'"
	

	FileDirectory default 
		forceNewFileNamed:  updateNumber asString, 'update', aSt, '.cs'
		do: [ :stream | self generateCS: extensionAndNumber fromUpdate: updateNumber on: stream].
! !

!MCRepositoryGroup methodsFor: '*scriptloader13' stamp: 'sd 3/15/2008 17:33'!
removeHTTPRepositoryLocationNamed: aRepositoryString
	
	| httpRepo others |
	httpRepo := repositories select: [:each | each isKindOf: MCHttpRepository]. 
	others := repositories reject: [:each | each isKindOf: MCHttpRepository].
	repositories := others, (httpRepo reject: [:each | each locationWithTrailingSlash = aRepositoryString]).
	self changed: #repositories! !
ScriptLoader initialize!
